@@ -1,5 +1,5 @@
 /* The combat-related actions of Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -339,6 +339,9 @@ int x, y, z, n;
 	  return A_ANY_NO_MATERIAL;
     }
     for_all_stack(x, y, defender) {
+	/* If we can't attack the unit, then we can't possibly overrun. */
+	if (uu_acp_to_attack(u2, defender->type) == 0)
+	  return A_ANY_ERROR;
 	/* (should test if units here can be attacked en masse) */
     	/* (should prorate ammo needs by intensity of overrun) */
     	if (!enough_ammo(unit2, defender))
@@ -503,6 +506,9 @@ int m;
       return A_ANY_TOO_NEAR;
     if (unit2->side != NULL && unit2->side == unit3->side)
       return A_ANY_ERROR;
+    /* Gunners won't shoot at anything they know they can't hit. */
+    if ((uu_fire_hit(u2, u3) != -1 ? uu_fire_hit(u2, u3) : uu_hit(u2, u3)) == 0)
+      return A_ANY_ERROR;
     /* Check intervening elevations. */
     if (found_blocking_elevation(u2, ux, uy, uz, u3, unit3->x, unit3->y, unit3->z))
       return A_ANY_ERROR;
@@ -1960,7 +1966,9 @@ int u;
     int u2;
 	
     for_all_unit_types(u2) {
-	if (uu_acp_to_attack(u, u2) > 0 && uu_hit(u, u2) > 0 && uu_damage(u, u2) > 0)
+	if (uu_acp_to_attack(u, u2) > 0
+	    && uu_hit(u, u2) > 0
+	    && uu_damage(u, u2) > 0)
 	  return TRUE;
     }
     return FALSE;
@@ -1998,7 +2006,9 @@ int u;
     int u2;
 	
     for_all_unit_types(u2) {
-	if (uu_acp_to_capture(u, u2) > 0
+	/* Capture can happen by both direct action and as result of an
+	   attack. */
+	if ((uu_acp_to_attack(u, u2) > 0 || uu_acp_to_capture(u, u2) > 0)
 	    && (uu_capture(u, u2) > 0 || uu_indep_capture(u, u2) > 0))
 	  return TRUE;
     }
