@@ -27,6 +27,14 @@ any later version.  See the file COPYING.  */
 #include "ai.h"
 #include "system.h"
 
+/* Elements of bitmask controlling display updates. */
+
+#define UPDATE_RIGHTNOW 1
+#define UPDATE_COVER 2
+#define UPDATE_TEMP 4
+#define UPDATE_CLOUDS 8
+#define UPDATE_WINDS 16
+
 /* Declarations of globally visible globals. */
 
 extern int typesdefined;
@@ -114,7 +122,7 @@ extern void update_side_display PARAMS ((Side *side, Side *side2, int rightnow))
 extern void update_unit_display PARAMS ((Side *side, Unit *unit, int rightnow));
 extern void update_unit_acp_display PARAMS ((Side *side, Unit *unit, int rightnow));
 extern void update_message_display PARAMS ((Side *side, Side *side2, char *str, int rightnow));
-extern void update_cell_display PARAMS ((Side *side, int x, int y, int rightnow));
+extern void update_cell_display PARAMS ((Side *side, int x, int y, int flags));
 extern void update_all_progress_displays PARAMS ((char *str, int s));
 extern void update_everything PARAMS ((void));
 extern void flush_display_buffers PARAMS ((Side *side));
