@@ -1078,12 +1078,14 @@ ImageFamily *imf;
 static int tmpbw;  /* work around Think C bug */
 
 int
-emblem_position(uimg, ename, eimg, sw, sh, exxp, eyyp, ewp, ehp)
-Image *uimg, *eimg;
+emblem_position(uimg, ename, eimf, sw, sh, exxp, eyyp, ewp, ehp)
+Image *uimg;
 char *ename;
+ImageFamily *eimf;
 int sw, sh, *exxp, *eyyp, *ewp, *ehp;
 {
-    int ex, ey, ew, eh, bx, by, bw, bh, overlap;
+    int ew1, eh1, ex, ey, ew, eh, bx, by, bw, bh, overlap;
+    Image *eimg;
 
     if (uimg
 	&& uimg->embedname
@@ -1098,12 +1100,29 @@ int sw, sh, *exxp, *eyyp, *ewp, *ehp;
     if (uimg && uimg->embedw > 0 && uimg->embedh > 0) {
 	ew = uimg->embedw;  eh = uimg->embedh;
     } else {
-	ew = min(sw, max(8, sw / 4));  eh = min(sh, max(8, sh / 4));
+	ew1 = min(sw, max(8, sw / 4));  eh1 = min(sh, max(8, sh / 4));
+	if (eimf != NULL) {
+	    eimg = best_image(eimf, ew1, eh1);
+	}
+	if (eimg) {
+	    ew = eimg->w;  eh = eimg->h;
+	    /* Make a default 8x6 size for a solid color emblem. */
+	    if (ew == 1 && eh == 1) {
+		ew = 8;  eh = 6;
+	    }
+	} else {
+	    ew = ew1;  eh = eh1;
+	}
     }
     /* Position the emblem, either explicitly, or default to UR corner
-	   (note that we need the emblem's width to do this) */
+       (note that we need the emblem's width to do this) */
     if (uimg && uimg->embedx >= 0 && uimg->embedy >= 0) {
 	ex = uimg->embedx;  ey = uimg->embedy;
+	/* Don't let the emblem stick out of the unit's area. */
+	if (ex + ew > sw)
+	  ex = sw - ew;
+	if (ey + eh > sh)
+	  ey = sh - eh;
     } else if (uimg && (uimg->bboxw != uimg->w || uimg->bboxh != uimg->h)) {
 	overlap = FALSE;
 	/* Scale bounding box by space given to image. */
