@@ -1,5 +1,5 @@
 /* Implementation of the "mplayer" AI in Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -7,13 +7,13 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern int select_by_weight PARAMS ((int *arr, int numvals));
-extern int carryable PARAMS ((int u));
-extern int accelerable PARAMS ((int u));
-extern int accelerator PARAMS ((int u1, int u2));
+extern int select_by_weight(int *arr, int numvals);
+extern int carryable(int u);
+extern int accelerable(int u);
+extern int accelerator(int u1, int u2);
 #include "kpublic.h"
-extern void try_to_draw PARAMS ((Side *side, int flag, char *ainame));
-extern void give_up PARAMS ((Side *side, char *ainame));
+extern void try_to_draw(Side *side, int flag, char *ainame);
+extern void give_up(Side *side, char *ainame);
 
 extern int bhw_max;
 
@@ -30,13 +30,7 @@ typedef enum a_game_class {
     gc_none,
     gc_standard,
     gc_time,
-
-// --- ADVANCED GAME SUPPORT ---------------------------------------
-
     gc_advanced
-
-// -------------------------------------------------------------
-
 } GameClass;
 
 static GameClass game_class = gc_none;
@@ -164,81 +158,76 @@ typedef struct a_theater {
 
 /* Local function declarations. */
 
-// -- COLONIZER SUPPORT -----------------------------------------
-
+static void mplayer_init(Side *side);
+static void mplayer_init_turn(Side *side);
+static void create_strategy(Side *side);
+static void reset_strategy(Side *side);
+static void analyze_the_game(Side *side);
+static void determine_subgoals(Side *side);
+static void review_theaters(Side *side);
+static void create_initial_theaters(Side *side);
+static Theater *create_theater(Side *side);
+static void remove_theater(Side *side, Theater *theater);
+static void remove_small_theaters(Side *side);
+static void compute_theater_bounds(Side *side);
+static void review_goals(Side *side);
+static void review_units(Side *side);
+static void update_side_strategy(Side *side);
+static void decide_theater_needs(Side *side, Theater *theater);
+static void update_unit_plans(Side *side);
+static void update_unit_plans_randomly(Side *side);
+static void estimate_strengths(Side *side);
+static void decide_resignation(Side *side);
+static void add_goal(Side *side, Goal *goal);
+static Goal *has_goal(Side *side, GoalType goaltype);
+static Goal *has_unsatisfied_goal(Side *side, GoalType goaltype);
+static void mplayer_decide_plan(Side *side, Unit *unit);
+static int need_this_type_to_explore(Side *side, int u);
+/* static int compare_weights(struct weightelt *w1, struct weightelt *w2); */
+static void assign_to_exploration(Side *side, Unit *unit);
+static void assign_explorer_to_theater(Side *side, Unit *unit, Theater *theater);
+static int need_this_type_to_build_explorers(Side *side, int u);
+static void assign_to_explorer_construction(Side *side, Unit *unit);
+static void assign_to_offense(Side *side, Unit *unit);
+static void assign_to_offense_support(Side *side, Unit *unit);
+static int mplayer_adjust_plan(Side *side, Unit *unit);
+static int type_can_build_attackers(Side *side, int u);
+static int preferred_build_type(Side *side, Unit *unit, int plantype);
+static int need_more_transportation(Side *side);
+static void assign_to_defense(Side *side, Unit *unit);
+static void assign_to_defense_support(Side *side, Unit *unit);
+static int assign_to_research_on(Side *side, Unit *unit, int u2);
+static int can_research_on(int u, int u2);
+static int needs_research(Side *side, int u);
+static int mplayer_guide_explorer(Side *side, Unit *unit);
+static int probably_explorable(Side *side, int x, int y, int u);
+static int build_base_for_self(Side *side, Unit *unit);
+static int build_base_for_others(Side *side, Unit *unit);
+static int build_depot_for_self(Side *side, Unit *unit);
 static void assign_to_colonize(Side *side, Unit *unit);
 static void assign_to_improve(Side *side, Unit *unit);
 static int type_can_build_colonizers(Side *side, int u);
+static void mplayer_react_to_action_result(Side *side, Unit *unit, int rslt);
+static void mplayer_react_to_task_result(Side *side, Unit *unit, Task *task, TaskOutcome rslt);
+static void change_to_adjacent_theater(Side *side, Unit *unit);
+static int desired_direction_impassable(Unit *unit, int x, int y);
+static int could_be_ferried(Unit *unit, int x, int y);
+static int blocked_by_enemy(Unit *unit, int x, int y, int shortest);
+static int attack_blockage(Side *side, Unit *unit, int x, int y, int shortest);
+static void mplayer_react_to_new_side(Side *side, Side *side2);
+static void mplayer_finish_movement(Side *side);
+static Unit *search_for_available_transport(Unit *unit, int purpose);
+static void rethink_plan(Unit *unit);
+static int enemy_close_by(Side *side, Unit *unit, int dist, int *xp, int *yp);
+static void mplayer_receive_message(Side *side, Side *sender, char *str);
+static char *mplayer_at_desig(Side *side, int x, int y);
+static int mplayer_theater_at(Side *side, int x, int y);
+static int mplayer_read_strengths(Side *side);
+static Obj *mplayer_save_state(Side *side);
 
-// ----------------------------------------------------------
+static void mplayer_react_to_unit_loss(Side *side, Unit *unit);
 
-static void mplayer_init PARAMS ((Side *side));
-static void mplayer_init_turn PARAMS ((Side *side));
-static void create_strategy PARAMS ((Side *side));
-static void reset_strategy PARAMS ((Side *side));
-static void analyze_the_game PARAMS ((Side *side));
-static void determine_subgoals PARAMS ((Side *side));
-static void review_theaters PARAMS ((Side *side));
-static void create_initial_theaters PARAMS ((Side *side));
-static Theater *create_theater PARAMS ((Side *side));
-static void remove_theater PARAMS ((Side *side, Theater *theater));
-static void remove_small_theaters PARAMS ((Side *side));
-static void compute_theater_bounds PARAMS ((Side *side));
-static void review_goals PARAMS ((Side *side));
-static void review_units PARAMS ((Side *side));
-static void update_side_strategy PARAMS ((Side *side));
-static void decide_theater_needs PARAMS ((Side *side, Theater *theater));
-static void update_unit_plans PARAMS ((Side *side));
-static void update_unit_plans_randomly PARAMS ((Side *side));
-static void estimate_strengths PARAMS ((Side *side));
-static void decide_resignation PARAMS ((Side *side));
-static void add_goal PARAMS ((Side *side, Goal *goal));
-static Goal *has_goal PARAMS ((Side *side, GoalType goaltype));
-static Goal *has_unsatisfied_goal PARAMS ((Side *side, GoalType goaltype));
-static void mplayer_decide_plan PARAMS ((Side *side, Unit *unit));
-static int need_this_type_to_explore PARAMS ((Side *side, int u));
-/* static int compare_weights PARAMS ((struct weightelt *w1, struct weightelt *w2)); */
-static void assign_to_exploration PARAMS ((Side *side, Unit *unit));
-static void assign_explorer_to_theater PARAMS ((Side *side, Unit *unit, Theater *theater));
-static int need_this_type_to_build_explorers PARAMS ((Side *side, int u));
-static void assign_to_explorer_construction PARAMS ((Side *side, Unit *unit));
-static void assign_to_offense PARAMS ((Side *side, Unit *unit));
-static void assign_to_offense_support PARAMS ((Side *side, Unit *unit));
-static int mplayer_adjust_plan PARAMS ((Side *side, Unit *unit));
-static int type_can_build_attackers PARAMS ((Side *side, int u));
-static int preferred_build_type PARAMS ((Side *side, Unit *unit, int plantype));
-static int need_more_transportation PARAMS ((Side *side));
-static void assign_to_defense PARAMS ((Side *side, Unit *unit));
-static void assign_to_defense_support PARAMS ((Side *side, Unit *unit));
-static int assign_to_research_on PARAMS ((Side *side, Unit *unit, int u2));
-static int can_research_on PARAMS ((int u, int u2));
-static int needs_research PARAMS ((Side *side, int u));
-static int mplayer_guide_explorer PARAMS ((Side *side, Unit *unit));
-static int probably_explorable PARAMS ((Side *side, int x, int y, int u));
-static int build_base_for_self PARAMS ((Side *side, Unit *unit));
-static int build_base_for_others PARAMS ((Side *side, Unit *unit));
-static int build_depot_for_self PARAMS ((Side *side, Unit *unit));
-static void mplayer_react_to_action_result PARAMS ((Side *side, Unit *unit, int rslt));
-static void mplayer_react_to_task_result PARAMS ((Side *side, Unit *unit, Task *task, TaskOutcome rslt));
-static void change_to_adjacent_theater PARAMS ((Side *side, Unit *unit));
-static int desired_direction_impassable PARAMS ((Unit *unit, int x, int y));
-static int could_be_ferried PARAMS ((Unit *unit, int x, int y));
-static int blocked_by_enemy PARAMS ((Unit *unit, int x, int y, int shortest));
-static int attack_blockage PARAMS ((Side *side, Unit *unit, int x, int y, int shortest));
-static void mplayer_react_to_new_side PARAMS ((Side *side, Side *side2));
-static void mplayer_finish_movement PARAMS ((Side *side));
-static Unit *search_for_available_transport PARAMS ((Unit *unit, int purpose));
-static void rethink_plan PARAMS ((Unit *unit));
-static int enemy_close_by PARAMS ((Side *side, Unit *unit, int dist, int *xp, int *yp));
-static void mplayer_receive_message PARAMS ((Side *side, Side *sender, char *str));
-static char *mplayer_at_desig PARAMS ((Side *side, int x, int y));
-static int mplayer_theater_at PARAMS ((Side *side, int x, int y));
-static int mplayer_read_strengths PARAMS ((Side *side));
-static Obj *mplayer_save_state PARAMS ((Side *side));
-
-static void mplayer_react_to_unit_loss PARAMS ((Side *side, Unit *unit));
-
-static int compare_weights PARAMS ((const void *w1, const void *w2));
+static int compare_weights(const void *w1, const void *w2);
 
 /* This is the set of operations that generic code will use. */
 
@@ -279,15 +268,10 @@ find_game_class()
 	if (strcmp(m->name, "time") == 0
 	    || (m->origmodulename && strcmp(m->origmodulename, "time") == 0))
 	  return gc_time;
-
-// --- ADVANCED GAME SUPPORT ------------------------------------
-
     	else if (strcmp(m->name, "advanced") == 0
-	    || (m->origmodulename && strcmp(m->origmodulename, "advanced") == 0))
+		 || (m->origmodulename
+		     && strcmp(m->origmodulename, "advanced") == 0))
 	  return gc_advanced;
-
-// ----------------------------------------------------------
-
     }
     return gc_standard;
 }
@@ -1760,16 +1744,10 @@ Unit *unit;
       case PLAN_PASSIVE:
       case PLAN_NONE:
 	if (mobile(u)) {
-
-// --- COLONIZER SUPPORT ------------------------------------------
-
 	    if (u_colonizer(u)) {
 		assign_to_colonize(side, unit);
 		return;
 	    }
-
-// -------------------------------------------------------------
-
 	    /* Maybe assign to exploration. */
 	    if (has_goal(side, GOAL_WORLD_KNOWN)) {
 		if (need_this_type_to_explore(side, u)) {
@@ -1810,19 +1788,12 @@ Unit *unit;
       case PLAN_OFFENSIVE:
 	/* leave plan alone */
 	break;
-
-// --- COLONIZER SUPPORT -----------------------------
-
       case PLAN_COLONIZING:
 	/* leave plan alone */
 	break;
-
       case PLAN_IMPROVING:
 	/* leave plan alone */
 	break;
-
-// ------------------------------------------------
-
       case PLAN_EXPLORATORY:
 	/* leave plan alone */
 	break;
@@ -2017,8 +1988,6 @@ Unit *unit;
     DMprintf("%s assigned to explorer construction\n", unit_desig(unit));
 }
 
-// -- COLONIZER SUPPORT ------------------------------------
-
 static void
 assign_to_colonize(side, unit)
 Side *side;
@@ -2029,8 +1998,6 @@ Unit *unit;
     DMprintf("%s assigned to colonize\n", unit_desig(unit));
 }
 
-// -- COLONIZER SUPPORT ------------------------------------
-
 static void
 assign_to_improve(side, unit)
 Side *side;
@@ -2041,8 +2008,6 @@ Unit *unit;
     DMprintf("%s assigned to improve\n", unit_desig(unit));
 }
 
-// ------------------------------------------------------
-
 static void
 assign_to_offense(side, unit)
 Side *side;
@@ -2153,8 +2118,6 @@ int u;
     return FALSE;
 }
 
-// --- COLONIZER SUPPORT -----------------------------------
-
 static int
 type_can_build_colonizers(side, u)
 Side *side;
@@ -2172,8 +2135,6 @@ int u;
     return FALSE;
 }
 
-// ------------------------------------------------------
-
 /* For the given side and unit and plan, calculate the right type of
    unit to build. */
 
@@ -2275,42 +2236,39 @@ int plantype;
 		    prefs[u2] = (20 * sumfringe) / totfringe;
 		    /* Prefer types that are quicker to build. */
 		    prefs[u2] /= max(1, est / 8);
-
-// --- COLONIZER SUPPORT ---------------------------------------------
-
-		} else	 if (plantype == PLAN_COLONIZING) {
-		    	/* First eliminate non-colonizing units. */
-		    	if (!u_colonizer(u2)) {
-				prefs[u2] = 0;
-		    	/* Weight unit type by effectiveness against known enemies. */
-		    	} else {
-			    for_all_unit_types(u3) {
-				if (enemytypes[u3] > 0) {
-				    if (uu_zz_bhw(u2, u3) > 0) {
-					prefs[u2] += ((uu_zz_bhw(u2, u3) * 100) / bhw_max) * enemytypes[u3];
-				    }
-				    if (uu_zz_bcw(u2, u3) > 0) {
-					prefs[u2] += uu_zz_bcw(u2, u3) * enemytypes[u3];
-				    }
+		} else if (plantype == PLAN_COLONIZING) {
+		    /* First eliminate non-colonizing units. */
+		    if (!u_colonizer(u2)) {
+			prefs[u2] = 0;
+		    	/* Weight unit type by effectiveness against
+                           known enemies. */
+		    } else {
+			for_all_unit_types(u3) {
+			    if (enemytypes[u3] > 0) {
+				if (uu_zz_bhw(u2, u3) > 0) {
+				    prefs[u2] +=
+				      ((uu_zz_bhw(u2, u3) * 100) / bhw_max) * enemytypes[u3];
+				}
+				if (uu_zz_bcw(u2, u3) > 0) {
+				    prefs[u2] += uu_zz_bcw(u2, u3) * enemytypes[u3];
 				}
 			    }
-			    /* Prefer types that are quicker to build. */
-			    prefs[u2] /= max(1, est / 8);
-			}			
-
+			}
+			/* Prefer types that are quicker to build. */
+			prefs[u2] /= max(1, est / 8);
+		    }			
 		} else if (plantype == PLAN_IMPROVING) {
-			/* Eliminate all mobile units. */
-			if (mobile(u2))
-				prefs[u2] = 0;
-
-// ---------------------------------------------------------------
-
+		    /* Eliminate all mobile units. */
+		    if (mobile(u2))
+		      prefs[u2] = 0;
 		} else {
-		    /* Weight unit type by effectiveness against known enemies. */
+		    /* Weight unit type by effectiveness against known
+                       enemies. */
 		    for_all_unit_types(u3) {
 			if (enemytypes[u3] > 0) {
 			    if (uu_zz_bhw(u2, u3) > 0) {
-				prefs[u2] += ((uu_zz_bhw(u2, u3) * 100) / bhw_max) * enemytypes[u3];
+				prefs[u2] +=
+				  ((uu_zz_bhw(u2, u3) * 100) / bhw_max) * enemytypes[u3];
 			    }
 			    if (uu_zz_bcw(u2, u3) > 0) {
 				prefs[u2] += uu_zz_bcw(u2, u3) * enemytypes[u3];
@@ -2325,8 +2283,9 @@ int plantype;
 	    }
 	}
     }
-    /* Units that can't even get out of the builder get their preference
-       cut.  This helps prevent the construction of large ships in Denver. */
+    /* Units that can't even get out of the builder get their
+       preference cut.  This helps prevent the construction of large
+       ships in Denver. */
     /* (should allow if units would have some other way to leave) */
     if (1 /* plantype == PLAN_EXPLORATORY */) {
 	for_all_unit_types(u2) {
