@@ -524,7 +524,7 @@ unit_handle(side, unit)
 Side *side;
 Unit *unit;
 {
-    char *utypename, *fmtstr;
+    char *utypename, *fmtstr, smallbuf[40], sidebuf[100];
     Side *side2, *side3;
     Obj *frest, *fmt1;
 
@@ -541,6 +541,36 @@ Unit *unit;
     if (side != NULL && unit == side->self_unit)
       return "you";
     unitbuf[0] = '\0';
+    /* Decide how to identify the side.  If the unit's original side
+       is not its current side, list both of them. */
+    side2 = unit->side;
+    side3 = NULL;
+    if (unit->origside != NULL && side2 != unit->origside) {
+	side3 = unit->origside;
+    }
+    sidebuf[0] = '\0';
+    if (side2 == NULL) {
+	strcat(sidebuf, "the");
+    } else if (side2 == side) {
+	strcat(sidebuf, "your");
+    } else {
+	strcat(sidebuf, "the ");
+	strcat(sidebuf, side_adjective(side2));
+	if (side3 != NULL)
+	  strcat(sidebuf, "-held");
+    }
+    if (side3 != NULL) {
+	if (side3 == side) {
+	    strcat(sidebuf, " (your)");
+	} else {
+	    strcat(sidebuf, " (");
+	    strcat(sidebuf, side_adjective(side3));
+	    strcat(sidebuf, ")");
+	}
+    }
+    /* Now add the unit's unique description. */
+    utypename = u_type_name(unit->type);
+    /* If we have special formatting info, interpret it. */
     if (u_desc_format(unit->type) != lispnil) {
 	for_all_list(u_desc_format(unit->type), frest) {
 	    fmt1 = car(frest);
@@ -550,6 +580,13 @@ Unit *unit;
 		fmtstr = c_string(fmt1);
 		if (strcmp(fmtstr, "name") == 0) {
 		    strcat(unitbuf, (unit->name ? unit->name : "anon"));
+		} else if (strcmp(fmtstr, "position") == 0) {
+		    sprintf(smallbuf, "%d,%d", unit->x, unit->y);
+		    strcat(unitbuf, smallbuf);
+		} else if (strcmp(fmtstr, "side") == 0) {
+		    strcat(unitbuf, sidebuf);
+		} else if (strcmp(fmtstr, "type") == 0) {
+		    strcat(unitbuf, utypename);
 		} else if (strcmp(fmtstr, "side-name") == 0) {
 		    strcat(unitbuf, side_name(unit->side));
 		} else if (strcmp(fmtstr, "side-adjective") == 0) {
@@ -562,36 +599,10 @@ Unit *unit;
 	    }
 	}
 	return unitbuf;
-    }
-    /* Decide how to identify the side.  If the unit's original side
-       is not its current side, list both of them. */
-    side2 = unit->side;
-    side3 = NULL;
-    if (unit->origside != NULL && side2 != unit->origside) {
-	side3 = unit->origside;
-    }
-    if (side2 == NULL) {
-	strcat(unitbuf, "the");
-    } else if (side2 == side) {
-	strcat(unitbuf, "your");
     } else {
-	strcat(unitbuf, "the ");
-	strcat(unitbuf, side_adjective(side2));
-	if (side3 != NULL)
-	  strcat(unitbuf, "-held");
+	strcat(unitbuf, sidebuf);
+	strcat(unitbuf, " ");
     }
-    if (side3 != NULL) {
-	if (side3 == side) {
-	    strcat(unitbuf, " (your)");
-	} else {
-	    strcat(unitbuf, " (");
-	    strcat(unitbuf, side_adjective(side3));
-	    strcat(unitbuf, ")");
-	}
-    }
-    strcat(unitbuf, " ");
-    /* Now add the unit's unique description. */
-    utypename = u_type_name(unit->type);
     if (unit->name) {
 	tprintf(unitbuf, "%s %s", utypename, unit->name);
     } else if (unit->number > 0) {
@@ -1884,7 +1895,7 @@ Unit *unit;
     char goalbuf[BUFSIZE];
     int i;
     Plan *plan = unit->plan;
-    Task *task = plan->tasks;
+    Task *task;
 
     if (plan == NULL) {
 	buf[0] = '\0';
