@@ -7,33 +7,28 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern int target_visible PARAMS ((Unit *unit, Task *task));
+extern int target_visible(Unit *unit, Task *task);
 #include "kernel.h"
-extern int repair_if_damaged PARAMS ((Unit *unit));
+extern int repair_if_damaged(Unit *unit);
 
 extern short any_auto_repair;
 
-// --- COLONIZER SUPPORT -------------------------------------
+static void plan_passive(Unit *unit, int try);
+static void plan_offense(Unit *unit);
+static void plan_offense_support(Unit *unit);
+static void plan_defense(Unit *unit);
+static void plan_exploration(Unit *unit);
+static void plan_explorer_support(Unit *unit);
+static void plan_improve(Unit *unit);
+static void plan_colonize(Unit *unit);
+static void plan_colonizer_support(Unit *unit);
+static int good_cell_to_colonize(int u, Unit *unit);
+static void plan_random(Unit *unit);
+static void wake_at(int x, int y);
 
-static void plan_improve PARAMS ((Unit *unit));
-static void plan_colonize PARAMS ((Unit *unit));
-static void plan_colonizer_support PARAMS ((Unit *unit));
-static int good_cell_to_colonize PARAMS((int u, Unit *unit));
+static int alternate_target_here(int x, int y);
 
-// -------------------------------------------------------
-
-static void plan_passive PARAMS ((Unit *unit, int try));
-static void plan_offense PARAMS ((Unit *unit));
-static void plan_offense_support PARAMS ((Unit *unit));
-static void plan_defense PARAMS ((Unit *unit));
-static void plan_exploration PARAMS ((Unit *unit));
-static void plan_explorer_support PARAMS ((Unit *unit));
-static void plan_random PARAMS ((Unit *unit));
-static void wake_at PARAMS ((int x, int y));
-
-static int alternate_target_here PARAMS ((int x, int y));
-
-static int side_planning_to_capture PARAMS ((Side *side, int u, int x, int y));
+static int side_planning_to_capture(Side *side, int u, int x, int y);
 
 #define CLEAR_AGENDA 99
 
@@ -252,19 +247,12 @@ int try;
       case PLAN_EXPLORATORY:
 	plan_exploration(unit);
 	break;
-
-// --- COLONIZER SUPPORT --------------------------
-
       case PLAN_COLONIZING:
 	plan_colonize(unit);
 	break;
-
       case PLAN_IMPROVING:
 	plan_improve(unit);
 	break;
-
-// --------------------------------------------
-
       case PLAN_RANDOM:
 	plan_random(unit);
 	break;
@@ -313,7 +301,7 @@ Unit *unit;
     return FALSE;
 }
 
-int task_is_in_agenda PARAMS ((Plan *plan, Task *task));
+int task_is_in_agenda(Plan *plan, Task *task);
 
 /* See if there are any standing orders that currently apply to the given unit,
    and schedule a task if so.  Return TRUE if a task was added. */
@@ -376,7 +364,7 @@ int addtask;
     return FALSE;
 }
 
-int tasks_match PARAMS ((Task *task1, Task *task2));
+int tasks_match(Task *task1, Task *task2);
 
 int
 task_is_in_agenda(plan, task)
@@ -461,7 +449,7 @@ int try;
 
 /* A unit operating offensively advances and attacks when possible. */
 
-int find_alternate_hit_target PARAMS ((Unit *unit, Task *task, int *xp, int *yp));
+int find_alternate_hit_target(Unit *unit, Task *task, int *xp, int *yp);
 
 static void
 plan_offense(unit)
@@ -858,196 +846,193 @@ Unit *unit;
     }
 }
 
-// --- COLONIZER SUPPORT ----------------------------------------------
-
 static void
 plan_colonize(Unit *unit)
 {
-	Task *task = unit->plan->tasks;
-	Plan *plan = unit->plan;
-	int 	type[MAXUTYPES];
-	int 	numtypes = 0;
-	int 	u = unit->type;
-	int 	u2;
+    Task *task = unit->plan->tasks;
+    Plan *plan = unit->plan;
+    int 	type[MAXUTYPES];
+    int 	numtypes = 0;
+    int 	u = unit->type;
+    int 	u2;
 
-	/* Maybe set building task for colonizers. */
-	if (u_colonizer(u)) {
-		/* Pick an advanced unit type to build. */
-		for_all_unit_types(u2) {
-		    	if (u_advanced(u2) 
-		    	    && could_create(u, u2)
-		    	    && type_allowed_on_side(u2, unit->side)) {
-					type[numtypes] = u2;
-					numtypes++;
-			}
+    /* Maybe set building task for colonizers. */
+    if (u_colonizer(u)) {
+	/* Pick an advanced unit type to build. */
+	for_all_unit_types(u2) {
+	    if (u_advanced(u2) 
+		&& could_create(u, u2)
+		&& type_allowed_on_side(u2, unit->side)) {
+		type[numtypes] = u2;
+		numtypes++;
+	    }
+	}
+	if (numtypes) {
+	    u2 = type[xrandom(numtypes)];
+	    if (task == NULL || task->type != TASK_BUILD) {
+		/* First test if we have found a good spot to settle. */
+		if(good_cell_to_colonize(u2, unit)) {
+		    /* Initiate construction if spot is OK. */
+		    set_build_task(unit, u2, 1);
+		    DMprintf("%s colonizing by building %s\n", 
+			     unit_desig(unit), u_type_name(u2));
 		}
-		if (numtypes) {
-			u2 = type[xrandom(numtypes)];
-			if (task == NULL || task->type != TASK_BUILD) {
-				/* First test if we have found a good spot to settle. */
-				if(good_cell_to_colonize(u2, unit)) {
-					/* Initiate construction if spot is OK. */
-					set_build_task(unit, u2, 1);
-					DMprintf("%s colonizing by building %s\n", 
-							unit_desig(unit), u_type_name(u2));
-				}
-			} else DMprintf("%s already building, leaving alone\n", 
-						unit_desig(unit));
-		} else DMprintf("%s has no way to colonize\n", 
-					unit_desig(unit));
-	}
-	/* Then execute task. */
-	if (unit->plan->tasks) {
-		execute_task(unit);
-		return;
+	    } else DMprintf("%s already building, leaving alone\n", 
+			    unit_desig(unit));
+	} else DMprintf("%s has no way to colonize\n", 
+			unit_desig(unit));
+    }
+    /* Then execute task. */
+    if (unit->plan->tasks) {
+	execute_task(unit);
+	return;
 	/* No pending tasks. */
-	} else if (mobile(u)) {
+    } else if (mobile(u)) {
 	/* Let colonizer move in a random dir along straight line. */
-		set_move_dir_task(unit, random_dir(), xrandom(20));
-		return;
+	set_move_dir_task(unit, random_dir(), xrandom(20));
+	return;
 	/* Set a build task for non-colonizers. */
-	} else {
-		plan_colonizer_support(unit);
-		return;
-	}
-	/* Check again if we now have a task to execute. */
-	if (unit->plan->tasks) {
-		execute_task(unit);
-		/* Let colonizer move in a random dir along straight line if task failed. */
-		if (mobile(u) && unit->plan->last_task_outcome == TASK_FAILED)
-	    		set_move_dir_task(unit, random_dir(), xrandom(20));
+    } else {
+	plan_colonizer_support(unit);
+	return;
+    }
+    /* Check again if we now have a task to execute. */
+    if (unit->plan->tasks) {
+	execute_task(unit);
+	/* Let colonizer move in a random dir along straight line if task failed. */
+	if (mobile(u) && unit->plan->last_task_outcome == TASK_FAILED)
+	  set_move_dir_task(unit, random_dir(), xrandom(20));
 
 	/* Else maybe go to sleep. */
-	} else if (probability(10)) {
-		DMprintf("no tasks, going to sleep (dunno why)\n");
-		plan->asleep = TRUE;
-	}
+    } else if (probability(10)) {
+	DMprintf("no tasks, going to sleep (dunno why)\n");
+	plan->asleep = TRUE;
+    }
 }
 
 static void
 plan_colonizer_support(Unit *unit)
 {
-	int 	type[MAXUTYPES];
-	int 	numtypes = 0;
-    	int 	u;
+    int 	type[MAXUTYPES];
+    int 	numtypes = 0;
+    int 	u;
 
 	/* Load all colonizing types into type vector. */
-	for_all_unit_types(u) {
-		if (type_allowed_on_side(u, unit->side) 
-		    	&& could_create(unit->type, u)
-		    	&& u_colonizer(u)) {
-				type[numtypes] = u;
-				numtypes++;
-		} 
-	}
-	/* Then pick one of them at random. */
-	if (numtypes) {
-		u = type[xrandom(numtypes)];
-	    	DMprintf("%s supporting colonization by building %s\n",
-		     		unit_desig(unit), u_type_name(u));
-	    	push_build_task(unit, u, 1);
-		return;
+    for_all_unit_types(u) {
+	if (type_allowed_on_side(u, unit->side) 
+	    && could_create(unit->type, u)
+	    && u_colonizer(u)) {
+	    type[numtypes] = u;
+	    numtypes++;
+	} 
+    }
+    /* Then pick one of them at random. */
+    if (numtypes) {
+	u = type[xrandom(numtypes)];
+	DMprintf("%s supporting colonization by building %s\n",
+		 unit_desig(unit), u_type_name(u));
+	push_build_task(unit, u, 1);
+	return;
 	/* Load all possible types instead if we failed. */
-	} else for_all_unit_types(u) {
-		if (type_allowed_on_side(u, unit->side) 
-		    	&& could_create(unit->type, u)) {
-				type[numtypes] = u;
-				numtypes++;
-		} 
-	}
-	/* Then pick one of them at random. */
-	if (numtypes) {
-		u = type[xrandom(numtypes)];
-	    	DMprintf("%s can't build colonizers, building %s instead\n",
-		     		unit_desig(unit), u_type_name(u));
-	    	push_build_task(unit, u, 1);
-		return;
+    } else for_all_unit_types(u) {
+	if (type_allowed_on_side(u, unit->side) 
+	    && could_create(unit->type, u)) {
+	    type[numtypes] = u;
+	    numtypes++;
+	} 
+    }
+    /* Then pick one of them at random. */
+    if (numtypes) {
+	u = type[xrandom(numtypes)];
+	DMprintf("%s can't build colonizers, building %s instead\n",
+		 unit_desig(unit), u_type_name(u));
+	push_build_task(unit, u, 1);
+	return;
 	/* Nothing can be built. */
-	} else	DMprintf("Sorry, %s can't build anything!\n", unit_desig(unit));
+    } else	DMprintf("Sorry, %s can't build anything!\n", unit_desig(unit));
 }
 
 static void
 plan_improve(Unit *unit)
 {
-	int 	type[MAXUTYPES];
-	int 	numtypes = 0;
-    	int 	u;
+    int 	type[MAXUTYPES];
+    int 	numtypes = 0;
+    int 	u;
 
 	/* Load all immobile types (facilities) into type vector. */
-	for_all_unit_types(u) {
-		if (type_allowed_on_side(u, unit->side) 
-		    	&& could_create(unit->type, u)
-		    	&& !mobile(u)) {
-				type[numtypes] = u;
-				numtypes++;
-		} 
-	}
-	/* Then pick one of them at random. */
-	if (numtypes) {
-		u = type[xrandom(numtypes)];
-	    	DMprintf("%s improving itself by building %s\n",
-		     		unit_desig(unit), u_type_name(u));
-	    	push_build_task(unit, u, 1);
-		return;
+    for_all_unit_types(u) {
+	if (type_allowed_on_side(u, unit->side) 
+	    && could_create(unit->type, u)
+	    && !mobile(u)) {
+	    type[numtypes] = u;
+	    numtypes++;
+	} 
+    }
+    /* Then pick one of them at random. */
+    if (numtypes) {
+	u = type[xrandom(numtypes)];
+	DMprintf("%s improving itself by building %s\n",
+		 unit_desig(unit), u_type_name(u));
+	push_build_task(unit, u, 1);
+	return;
 	/* Load all possible types instead if we failed. */
-	} else for_all_unit_types(u) {
-		if (type_allowed_on_side(u, unit->side) 
-		    	&& could_create(unit->type, u)) {
-				type[numtypes] = u;
-				numtypes++;
-		} 
-	}
-	/* Then pick one of them at random. */
-	if (numtypes) {
-		u = type[xrandom(numtypes)];
-	    	DMprintf("%s can't build facility, building %s instead\n",
-		     		unit_desig(unit), u_type_name(u));
-	    	push_build_task(unit, u, 1);
-		return;
+    } else for_all_unit_types(u) {
+	if (type_allowed_on_side(u, unit->side) 
+	    && could_create(unit->type, u)) {
+	    type[numtypes] = u;
+	    numtypes++;
+	} 
+    }
+    /* Then pick one of them at random. */
+    if (numtypes) {
+	u = type[xrandom(numtypes)];
+	DMprintf("%s can't build facility, building %s instead\n",
+		 unit_desig(unit), u_type_name(u));
+	push_build_task(unit, u, 1);
+	return;
 	/* Nothing can be built. */
-	} else	DMprintf("Sorry, %s can't build anything!\n", unit_desig(unit));
+    } else	DMprintf("Sorry, %s can't build anything!\n", unit_desig(unit));
 }
 
 static int 
-good_cell_to_colonize(int u, Unit	*unit)
+good_cell_to_colonize(int u, Unit *unit)
 {
-	int 	x1, y1, m, supply[MAXMTYPES], maxsize = PROPHI;
-	Unit	*unit2;
+    int 	x1, y1, m, supply[MAXMTYPES], maxsize = PROPHI;
+    Unit	*unit2;
 			
-		/* First zero the supply vector. */
-	    	for_all_material_types (m)
-			supply[m] = 0;
-		/* Go through all cells within reach and compute supply of materials. */
-		for_all_cells_within_n_steps(unit->x, unit->y, u_reach(u), x1, y1) {
-		if (!inside_area(x1, y1))
-			continue;
-		/* Return FALSE if other city or enemy unit is nearby. */
-		for_all_stack(x1, y1, unit2) {
-			if (u_advanced(unit2->type) 
-			    || !trusted_side(unit2->side, unit->side))
-				return FALSE; 
-		}
-		/* Don't count supply in cells already used by others. */
-		if (user_at(x1, y1) != NOUSER)
-			continue;
-		/* Add the supply of materials from this cell. */
-	    	for_all_material_types (m)
-			supply[m] += tm_production(terrain_at(x1, y1), m); 
+    /* First zero the supply vector. */
+    for_all_material_types (m)
+      supply[m] = 0;
+    /* Go through all cells within reach and compute supply of materials. */
+    for_all_cells_within_n_steps(unit->x, unit->y, u_reach(u), x1, y1) {
+	if (!inside_area(x1, y1))
+	  continue;
+	/* Return FALSE if other city or enemy unit is nearby. */
+	for_all_stack(x1, y1, unit2) {
+	    if (u_advanced(unit2->type) 
+		|| !trusted_side(unit2->side, unit->side))
+	      return FALSE; 
 	}
-	/* Calculate max sustainable city size at this location. */
-	for_all_material_types (m) {
-		if (um_consumption_per_size(u, m) > 0)
-			maxsize = min(maxsize, (float) supply[m] / um_consumption_per_size(u, m));
-	}
-	/* Return FALSE if there is not enough food around 
+	/* Don't count supply in cells already used by others. */
+	if (user_at(x1, y1) != NOUSER)
+	  continue;
+	/* Add the supply of materials from this cell. */
+	for_all_material_types (m)
+	  supply[m] += tm_production(terrain_at(x1, y1), m); 
+    }
+    /* Calculate max sustainable city size at this location. */
+    for_all_material_types (m) {
+	if (um_consumption_per_size(u, m) > 0)
+	  maxsize =
+	    min(maxsize, (float) supply[m] / um_consumption_per_size(u, m));
+    }
+    /* Return FALSE if there is not enough food around 
 	to sustain the minimal size goal for this unit type. */
-	if (maxsize < u_minimal_size_goal(u))
-		return FALSE;
-	return TRUE;
+    if (maxsize < u_minimal_size_goal(u))
+      return FALSE;
+    return TRUE;
 }
 
-// ---------------------------------------------------------------------
-
 static void
 plan_exploration(unit)
 Unit *unit;
@@ -1545,8 +1530,8 @@ int x, y, m;
     return FALSE;
 }
 
-extern int repair_if_damaged PARAMS ((Unit *unit));
-extern int repairs_here PARAMS ((Unit *unit, int x, int y));
+extern int repair_if_damaged(Unit *unit);
+extern int repairs_here(Unit *unit, int x, int y);
 
 int
 repair_if_damaged(unit)
@@ -1771,20 +1756,19 @@ int u;
     return FALSE;
 }
 
-/* This is a semi-testing routine that basically picks something for the
-   unit to do without worrying about its validity.  The rest of the
-   system should function correctly no matter what this thing comes up with.
-   Piles of warnings are likely, but that's OK. */
+/* This is a semi-testing routine that basically picks something for
+   the unit to do without worrying about its validity.  The rest of
+   the system should function correctly no matter what this thing
+   comes up with.  Piles of warnings are likely, but that's OK. */
 
-/* (should actually have two modes for this - testing, which allows bad data,
-   and normal usage with no garbage generated, which is used with unintelligent
-   AIs) */
+/* (should actually have two modes for this - testing, which allows
+   bad data, and normal usage with no garbage generated, which is used
+   with unintelligent AIs) */
 
 static void
-plan_random(unit)
-Unit *unit;
+plan_random(Unit *unit)
 {
-    int dir, x1, y1, n;
+    int dir, x1, y1, n, randmtype;
     TaskType tasktype;
     Task *task;
     Action action;
@@ -1806,15 +1790,20 @@ Unit *unit;
 	    task = create_build_task(unit, xrandom(numutypes), xrandom(99));
 	    add_task(unit, CLEAR_AGENDA, task);
 	    break;
-	  case TASK_RESEARCH:
-	    task = create_task(tasktype);
-	    add_task(unit, CLEAR_AGENDA, task);
-	    break;
 	  case TASK_CAPTURE:
 	    dir = random_dir();
 	    point_in_dir(unit->x, unit->y, dir, &x1, &y1);
 	    set_capture_task(unit, x1, y1);
 	    break;
+	  case TASK_COLLECT:
+	    if (nummtypes > 0) {
+		randmtype = (flip_coin() ? xrandom(nummtypes) : NONMTYPE);
+	    	set_collect_task(unit, randmtype, unit->x, unit->y);
+	    }
+	    break;
+	  case TASK_DISBAND:
+	    set_disband_task(unit);
+	    break;
 	  case TASK_DO_ACTION:
 	    task = create_task(tasktype);
 	    add_task(unit, CLEAR_AGENDA, task);
@@ -1847,35 +1836,27 @@ Unit *unit;
 	    break;
 	  case TASK_PRODUCE:
 	    if (nummtypes > 0) {
-		task = create_produce_task(unit, (flip_coin() ? xrandom(nummtypes) : NONMTYPE), xrandom(100));
+		randmtype = (flip_coin() ? xrandom(nummtypes) : NONMTYPE);
+		task = create_produce_task(unit, randmtype, xrandom(100));
 		add_task(unit, CLEAR_AGENDA, task);
 	    }
 	    break;
 	  case TASK_REPAIR:
 	    set_repair_task(unit);
 	    break;
-	  case TASK_DISBAND:
-	    set_disband_task(unit);
+	  case TASK_RESEARCH:
+	    task = create_task(tasktype);
+	    add_task(unit, CLEAR_AGENDA, task);
 	    break;
 	  case TASK_RESUPPLY:
 	    if (nummtypes > 0) {
-		set_resupply_task(unit, (flip_coin() ? xrandom(nummtypes) : NONMTYPE));
+		randmtype = (flip_coin() ? xrandom(nummtypes) : NONMTYPE);
+		set_resupply_task(unit, randmtype);
 	    }
 	    break;
 	  case TASK_SENTRY:
 	    set_sentry_task(unit, xrandom(5));
 	    break;
-
-// --- CRASHING BUG FIX --------------------------------------------------------
-
-	  case TASK_COLLECT:
-	    if (nummtypes > 0) {
-	    	set_collect_task(unit, (flip_coin() ? xrandom(nummtypes) : NONMTYPE), unit->x, unit->y);
-	    }
-	    break;
-
-// -------------------------------------------------------------------------
-
 	  default:
 	    case_panic("task type", tasktype);
 	    break;
