@@ -144,29 +144,35 @@ init_run()
     highest_unit_priority = 9999;
     lowest_unit_priority = -1;
     for_all_unit_types(u) {
-        highest_unit_priority = min(highest_unit_priority, u_action_priority(u));
-        lowest_unit_priority = max(lowest_unit_priority, u_action_priority(u));
+        highest_unit_priority =
+	  min(highest_unit_priority, u_action_priority(u));
+        lowest_unit_priority =
+	  max(lowest_unit_priority, u_action_priority(u));
         for_all_sides_plus_indep(side) {
 	    if (side->action_priorities) {
-		highest_unit_priority = min(highest_unit_priority, side->action_priorities[u]);
-		lowest_unit_priority = max(lowest_unit_priority, side->action_priorities[u]);
+		highest_unit_priority =
+		  min(highest_unit_priority, side->action_priorities[u]);
+		lowest_unit_priority =
+		  max(lowest_unit_priority, side->action_priorities[u]);
 	    }
         }
     }
     for_all_units(unit) {
         if (unit->extras) {
-	    highest_unit_priority = min(highest_unit_priority, unit_extra_priority(unit));
-	    lowest_unit_priority = max(lowest_unit_priority, unit_extra_priority(unit));
+	    highest_unit_priority =
+	      min(highest_unit_priority, unit_extra_priority(unit));
+	    lowest_unit_priority =
+	      max(lowest_unit_priority, unit_extra_priority(unit));
         }
     }
 }
 
-/* This function does a (small, usually) amount of simulation, then returns.
-   It can be run multiple times at any time, will not go "too far".
-   It returns the number of actions that were actually performed. Other
-   important state changes (such a side finishing its turn or the turn
-   ending) are also counted as actions, so that this function's callers
-   will know that something was done. */
+/* This function does a (small, usually) amount of simulation, then
+   returns.  It can be run multiple times at any time, will not go
+   "too far".  It returns the number of actions that were actually
+   performed. Other important state changes (such a side finishing its
+   turn or the turn ending) are also counted as actions, so that this
+   function's callers will know that something was done. */
 
 int
 run_game(maxactions)
