@@ -1145,30 +1145,7 @@ run_environment()
 	for_all_interior_cells(x, y) {
 	    set_tmp2_at(x, y, raw_wind_at(x, y));
 	}
-	for_all_interior_cells(x, y) {
-	    int winddir = wind_dir_at(x, y);
-	    int windforce = wind_force_at(x, y), newwindforce;
-	    int t = terrain_at(x, y);
-	    int anychange;
-
-	    anychange = FALSE;
-	    if (probability(t_wind_variability(t))) {
-		winddir = (flip_coin() ? right_dir(winddir) : left_dir(winddir));
-		anychange = TRUE;
-	    }
-	    if (probability(t_wind_force_variability(t))) {	
-		newwindforce = windforce + (flip_coin() ? 1 : -1);
-		newwindforce = max(newwindforce, t_wind_force_min(t));
-		newwindforce = min(newwindforce, t_wind_force_max(t));
-		if (newwindforce != windforce) {
-		    windforce = newwindforce;
-		    anychange = TRUE;
-		}
-	    }
-	    if (anychange) {
-		set_wind_at(x, y, winddir, windforce);
-	    }
-	}
+	vary_winds();
 	if (g_wind_mix_range() > 0) {
 	    mix_winds();
 	}
@@ -1189,6 +1166,34 @@ run_environment()
     }
 }
 
+vary_winds()
+{
+    int x, y, t, wdir, wforce, newwforce, anychange;
+
+    for_all_interior_cells(x, y) {
+	wdir = wind_dir_at(x, y);
+	wforce = wind_force_at(x, y);
+	t = terrain_at(x, y);
+	anychange = FALSE;
+	if (probability(t_wind_variability(t))) {
+	    wdir = (flip_coin() ? right_dir(wdir) : left_dir(wdir));
+	    anychange = TRUE;
+	}
+	if (probability(t_wind_force_variability(t))) {	
+	    newwforce = wforce + (flip_coin() ? 1 : -1);
+	    newwforce = max(newwforce, t_wind_force_min(t));
+	    newwforce = min(newwforce, t_wind_force_max(t));
+	    if (newwforce != wforce) {
+		wforce = newwforce;
+		anychange = TRUE;
+	    }
+	}
+	if (anychange) {
+	    set_wind_at(x, y, wdir, wforce);
+	}
+    }
+}
+
 static void
 mix_winds()
 {
@@ -1210,14 +1215,21 @@ mix_winds()
 		++n;
 	    }
 	}
+	/* Over time, the rounding-down effect of division would
+	   causes all winds to diminish to zero.  Counteract by
+	   incrementing the sum. */
+	sumx += n - 1;  sumy += n - 1;
 	sumx = sumx / n;  sumy = sumy / n;
-	wdir = approx_dir(sumx, sumy);
-	wforce = distance(0, 0, sumx, sumy);
+	if (sumx == 0 && sumy == 0) {
+	    wdir = random_dir();
+	    wforce = 0;
+	} else {
+	    wdir = approx_dir(sumx, sumy);
+	    wforce = distance(0, 0, sumx, sumy);
+	}
 	t = terrain_at(x, y);
 	wforce = max(wforce, t_wind_force_min(t));
 	wforce = min(wforce, t_wind_force_max(t));
-	if (wforce < 0)
-	    wforce = 0;
 	set_wind_at(x, y, wdir, wforce);
     }
 }
@@ -1235,33 +1247,32 @@ int x, y;
     /* (should build layer mask and call cell updating once) */
     for_all_sides(side) {
 	if (all_see_all) {
-	    update_cell_display(side, x, y, 34);
-	    update_cell_display(side, x, y, 37);
-	    update_cell_display(side, x, y, 35);
+	    update_cell_display(side, x, y,
+				UPDATE_TEMP|UPDATE_CLOUDS|UPDATE_WINDS);
 	} else if (g_see_weather_always()
 	    ? (terrain_view(side, x, y) != UNSEEN)
 	    : (cover(side, x, y) > 0)) {
-	  if (temperatures_defined()) {
-	    oldview = temperature_view(side, x, y);
-	    if (oldview != temperature_at(x, y)) {
-		set_temperature_view(side, x, y, temperature_at(x, y));
-		update_cell_display(side, x, y, 34);
+	    if (temperatures_defined()) {
+		oldview = temperature_view(side, x, y);
+		if (oldview != temperature_at(x, y)) {
+		    set_temperature_view(side, x, y, temperature_at(x, y));
+		    update_cell_display(side, x, y, UPDATE_TEMP);
+		}
 	    }
-	  }
-	  if (clouds_defined()) {
-	    oldview = cloud_view(side, x, y);
-	    if (oldview != raw_cloud_at(x, y)) {
-		set_cloud_view(side, x, y, raw_cloud_at(x, y));
-		update_cell_display(side, x, y, 37);
+	    if (clouds_defined()) {
+		oldview = cloud_view(side, x, y);
+		if (oldview != raw_cloud_at(x, y)) {
+		    set_cloud_view(side, x, y, raw_cloud_at(x, y));
+		    update_cell_display(side, x, y, UPDATE_CLOUDS);
+		}
 	    }
-	  }
-	  if (winds_defined()) {
-	    oldview = wind_view(side, x, y);
-	    if (oldview != raw_wind_at(x, y)) {
-		set_wind_view(side, x, y, raw_wind_at(x, y));
-		update_cell_display(side, x, y, 35);
+	    if (winds_defined()) {
+		oldview = wind_view(side, x, y);
+		if (oldview != raw_wind_at(x, y)) {
+		    set_wind_view(side, x, y, raw_wind_at(x, y));
+		    update_cell_display(side, x, y, UPDATE_WINDS);
+		}
 	    }
-	  }
 	}
     }
 }
@@ -2323,7 +2334,7 @@ Side *side;
 		&& (oldside == side2 || trusted_side(oldside, side2))) {
 		add_cover(side2, x, y, -1);
 		/* Update coverage display. */
-		update_cell_display(side2, x, y, 36);
+		update_cell_display(side2, x, y, UPDATE_COVER);
 	   }
 	}
     }
