@@ -758,6 +758,8 @@ char *str;
     printf("To %s: %s\n", side_desig(side), str);
 }
 
+update_area_display() {}
+
 /* (should count # of calls to inactive and non-displayed side...) */
 
 void
@@ -1232,3 +1234,4 @@ serial_port_dialog()
 
 unit_advance_dialog(Unit *unit) { auto_pick_new_research(unit); }
 global_advance_dialog(Side *side, Unit *unit, int s) { auto_pick_new_research(unit); }
+unit_build_dialog(Unit *unit, Task *task) { return 0; }
