@@ -533,6 +533,7 @@ int x, y, *sxp, *syp;
 	error_is_bug = TRUE;
 	run_error("attempting to xform %d,%d", x, y);
     }
+    *sxp += vp->offsetx;  *syp += vp->offsety;
 }
 
 /* Similarly, but allowing 1/1000ths of cells as input.  Note that
@@ -681,6 +682,7 @@ int sx, sy, *xp, *yp, *xfp, *yfp;
 {
     int sxadj, sxfrac, syflipped, syfrac;
 
+    sx -= vp->offsetx;  sy -= vp->offsety;
     /* Flip the raw y and then scale to hex coords. */
     syflipped = vp->totsh - (vp->sy + sy);
     *yp = syflipped / vp->hch;
@@ -1011,9 +1013,16 @@ VP *vp;
     vp->totsw = area.width * vp->hw + hexagon_adjust(vp);
     if (area.xwrap && (vp->totsw > (vp->pxw - vp->hw)))
       vp->totsw += (vp->pxw - vp->hw);
-    /* Total scaled height is based on center-to-center height, plus an adjustment
-       to include the bottom parts of the bottom row. */
+    /* Total scaled height is based on center-to-center height, plus
+       an adjustment to include the bottom parts of the bottom row. */
     vp->totsh = area.height * vp->hch + (vp->hh - vp->hch);
+    if (vp->center) {
+	vp->offsetx = vp->offsety = 0;
+	if (vp->totsw < vp->pxw)
+	  vp->offsetx = (vp->pxw - vp->totsw) / 2;
+	if (vp->totsh < vp->pxh)
+	  vp->offsety = (vp->pxh - vp->totsh) / 2;
+    }
     vp->sxmin = hexagon_adjust(vp);  vp->symin = 0;
     /* Special-case wide viewports (a la Mac) for cylindrical worlds. */
     if (vp->wide_viewport && area.xwrap)
@@ -1169,10 +1178,10 @@ void (*text_callback) PARAMS ((int x1, int y1, int x1f, int y1f, char *str));
 
     incr = vp->latlong_interval;
     /* Draw only if the interval is not too small. */
-    xy_to_latlong(1, area.height - 2, 0, 0, &lat, &lon);
+    xy_to_latlong(area.halfwidth, area.height - 2, 0, 0, &lat, &lon);
     latlong_to_xy(lat, lon, &x1, &y1, &x1f, &y1f);
     latlong_to_xy(lat - incr, lon, &x2, &y2, &x2f, &y2f);
-    /* If a single interval down from the NW corner is off the map, then there
+    /* If a single interval down from the top middle is off the map, then there
        won't be any lines to plot anyway, so OK to escape. */
     if (!in_area(x2, y2))
       return;
@@ -1191,8 +1200,8 @@ void (*text_callback) PARAMS ((int x1, int y1, int x1f, int y1f, char *str));
 	xy_to_latlong(xxmin, ymin, 0, 0, &lat1, &lon1);
 	xy_to_latlong(xmax, ymax, 0, 0, &lat2, &lon2);
     } else {
-	lat1 = -75 * 60 + incr - 1;  lon1 = -180 * 60 + incr - 1;
-	lat2 = 75 * 60 - (incr - 1);  lon2 = 180 * 60 - (incr - 1);
+	lat1 = -75 * 60 +  incr - 1;   lon1 = -180 * 60 +  incr - 1;
+	lat2 =  75 * 60 - (incr - 1);  lon2 =  180 * 60 - (incr - 1);
     }
     latmin = (lat1 / incr) * incr;
     latmax = (lat2 / incr) * incr + incr;
@@ -1436,13 +1445,17 @@ Unit *unit;
 {
     int uview;
 
+    if (!in_play(unit))
+      return FALSE;
     if (unit->side == side)
       return TRUE;
-    if (side->see_all)
+    if (all_see_all || side->see_all)
       return TRUE;
     if (u_see_always(unit->type))
       return TRUE;
-    /* (should be true if see chance >= 100) */
+    if (cover(side, unit->x, unit->y) >= 1)
+      return TRUE;
+    /* (should be true only if see chance >= 100) */
     uview = unit_view(side, unit->x, unit->y);
     if (unit->type == vtype(uview)
 	&& side_number(unit->side) == vside(uview))
