@@ -1,5 +1,5 @@
 /* Units in Xconq.
-   Copyright (C) 1986-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -79,16 +79,12 @@ int *numlivebytype;
 
 /* The next number to use for a unit id. */
 
-// --- FIX OF SPORADIC CRASHES IN GRAPHICS AND THE MPLAYER -----------------
+/* Starting the unit->id list at 1 will cause crashes in
+   side_number(unit->side) when it is fed the ghost unit with id = 0,
+   which seems to exist even though it does not have a valid side. */
+/* However, this should be found and fixed - id == 0 means "invalid unit". */
 
-/* Starting the unit->id list at 1 will cause crashes in side_number(unit->side) when it is 
-fed the ghost unit with id = 0, which seems to exist even though it does not have a valid side. */
-
-int nextid = 0;
-
-//	int nextid = 1;
-
-// ---------------------------------------------------------------
+int nextid = 1;
 
 /* A cache of completenesses. */
 
@@ -105,12 +101,6 @@ static Side *tmpside_classtest;
 /* Advanced unit support. */
 short default_size = 0;		/* Default abstract size of unit */
 
-// --- REPLACED BY u_reach(type) ----------------------------------
-
-// short default_reach = 2;		/* Default size of unit's zone of influence */
-
-// ----------------------------------------------------------
-
 short default_usedcells = 0;	/* Number of cells being used by the unit */
 short default_maxcells = 1;	/* Default max number of cells that unit can use */
 short default_curadvance = -1;	/* Default advance being researched by new unit */
@@ -266,15 +256,7 @@ int type, makebrains;
 
     /* Advanced unit support. */
     newunit->size = default_size;
-
-// --- NEW REACH DEFINITION --------------------------
-
     newunit->reach = u_reach(type);
-
-//    newunit->reach = default_reach;
-
-// -----------------------------------------------
-
     newunit->usedcells = default_usedcells;
     newunit->maxcells = default_maxcells;
     newunit->population = default_population;
@@ -520,21 +502,7 @@ int x, y;
     enter_cell_aux(unit, x, y);
     /* Inevitable side-effect of appearing in the new location. */
     all_see_occupy(unit, x, y, TRUE);
-
-
-// --- USER LAYER FIX -----------------------------------------
-
     kick_out_enemy_users(unit->side, x, y);
-
-//    /* Kick out enemy users if we control the cell */
-//    if (user_at(x, y) != NULL 
-//    	&& (!user_at(x, y)->side || !trusted_side(user_at(x, y)->side, unit->side))) {
-//		user_at(x, y)->usedcells -=1;
-//    		set_user_at(x, y, NULL);
-//    }
-         
-// ----------------------------------------------------------
-
     return TRUE;
 }
 
@@ -1404,30 +1372,25 @@ Unit *unit;
 Side *side;
 {
     int u;
+
     if (unit == NULL)
       return FALSE;
     u = unit->type;
-
-// --- INDEPENDENT GHOST UNIT BUG FIX -------------------------------------------
-
-/* Call the new function below with the unit type as argument. */
-
-   return new_unit_allowed_on_side(u, side);
+    return new_unit_allowed_on_side(u, side);
 }
 
-/* It is crucial to pass the unit type instead of the unit itself as argument in cases where the test must be 
-applied before a new unit is created, to prevent the appearance of independent ghost units that never got 
-the correct side set. Fortunately, there is no need to pass a real unit since the test only uses the type. */
-
-/* New function which is called directly when the test is applied before creating a unit. */
+/* It is crucial to pass the unit type instead of the unit itself as
+   argument in cases where the test must be applied before a new unit
+   is created, to prevent the appearance of independent ghost units
+   that never got the correct side set. Fortunately, there is no need
+   to pass a real unit since the test only uses the type. */
 
 int
 new_unit_allowed_on_side(int u, Side *side)
 {
+    int u2, sum;
 
-// -----------------------------------------------------------------------
-
-     /* Test general limitations on the type. */
+    /* Test general limitations on the type. */
     if (!type_allowed_on_side(u, side))
       return FALSE;
     /* Test specific game limits. */
@@ -1436,8 +1399,6 @@ new_unit_allowed_on_side(int u, Side *side)
 	  return FALSE;
     }
     if (g_units_per_side_max() >= 0) {
-	int u2, sum;
-
 	sum = 0;
 	for_all_unit_types(u2) {
 	    sum += side->numunits[u2];
@@ -2639,48 +2600,29 @@ int u, s, x, y;
 
     if (!type_can_occupy_cell(u, x, y))
       return NULL;
-
-// --- INDEPENDENT GHOST UNIT BUG FIX --------------------------
-
-/* Check this BEFORE creating new unit! */
-
+    side2 = side_n(s);
+    /* Check this BEFORE creating new unit! */
     if (!new_unit_allowed_on_side(u, side2))
       return NULL;
-
-// -------------------------------------------------------
-
-	    newunit = create_unit(u, TRUE);
-    if (newunit != NULL) {
-	if (s != 0) {
-	    side2 = side_n(s);
-
-// --- INDEPENDENT GHOST UNIT BUG FIX --------------------------
-
-/* To late to check here since the unit already exists. */
-
-//	    if (unit_allowed_on_side(newunit, side2)) {
-
-	    	set_unit_side(newunit, side2);
-	    	set_unit_origside(newunit, side2);
-
-	    	/* (should ensure that any changed counts are set correctly also) */
-//	    }
-
-// -------------------------------------------------------
-
-	}
-	init_supply(newunit);
-	if (can_occupy_cell(newunit, x, y)) {
-	    enter_cell(newunit, x, y);
-	} else {
-	    return NULL;
-	}
-	update_cell_display(side, x, y, TRUE);
-	update_unit_display(side, newunit, TRUE);
-	return newunit;
+    newunit = create_unit(u, TRUE);
+    if (newunit == NULL)
+      return NULL;
+    if (s != 0) {
+	side2 = side_n(s);
+	set_unit_side(newunit, side2);
+	set_unit_origside(newunit, side2);
+	/* (should ensure that any changed counts are set correctly) */
+    }
+    init_supply(newunit);
+    if (can_occupy_cell(newunit, x, y)) {
+	enter_cell(newunit, x, y);
     } else {
+	/* (should undo creation of unit?) */
 	return NULL;
     }
+    update_cell_display(side, x, y, TRUE);
+    update_unit_display(side, newunit, TRUE);
+    return newunit;
 }
 
 /* Move a unit to a given location instantly, with all sides observing. */
