@@ -2004,8 +2004,8 @@ Module *module;
 		if (module->def_all
 		    || module->def_unit_ids
 		    || (unit->occupant
-			&& unit->transport->name == NULL
-			&& unit_symbol(unit->transport) == lispnil))
+			&& unit->name == NULL
+			&& unit_symbol(unit) == lispnil))
 
 // ---  SAVE GAME BUG FIX ----------------------------------------------------------
 
@@ -2020,16 +2020,23 @@ unit 0 will be assigned an already occupied id when the saved game is launced, c
 
 		/* Need this to get back into the right transport. */
 		if (unit->transport) {
-		    if (unit_symbol(unit->transport) != lispnil && !module->def_unit_ids) {
-			write_lisp_prop(key(K_IN), unit_symbol(unit->transport), lispnil, FALSE, TRUE, FALSE);
-		    } else if (unit->transport->name && !module->def_unit_ids) {
-			write_str_prop(key(K_IN), unit->transport->name, NULL, FALSE, FALSE);
+		    if (unit_symbol(unit->transport) != lispnil
+			&& !module->def_unit_ids) {
+			write_lisp_prop(key(K_IN),
+					unit_symbol(unit->transport),
+					lispnil, FALSE, TRUE, FALSE);
+		    } else if (unit->transport->name
+			       && !module->def_unit_ids) {
+			write_str_prop(key(K_IN), unit->transport->name,
+				       NULL, FALSE, FALSE);
 		    } else {
-			write_num_prop(key(K_IN), unit->transport->id, 0, FALSE, FALSE);
+			write_num_prop(key(K_IN), unit->transport->id,
+				       0, FALSE, FALSE);
 		    }
 		}
 		/* Always need this, because occupants may reference. */
-		write_lisp_prop(key(K_SYM), unit_symbol(unit), lispnil, FALSE, TRUE, FALSE);
+		write_lisp_prop(key(K_SYM), unit_symbol(unit), lispnil,
+				FALSE, TRUE, FALSE);
 		/* Write optional info about the units. */
 		if (module->def_all || module->def_unit_props)
 		  write_unit_properties(unit);
