@@ -10,45 +10,46 @@ any later version.  See the file COPYING.  */
 #include "kpublic.h"
 #include "tkconq.h"
 
-void really_do_design PARAMS ((Side *side));
+void really_do_design(Side *side);
 
-static void aux_add_terrain PARAMS ((Side *side, Map *map, int cancel));
-static void aux_add_terrain_2 PARAMS ((Side *side, Map *map, int cancel));
-static void do_add_terrain_2 PARAMS ((Side *side, Map *map, int t));
-static void aux_attack PARAMS ((Side *side, Map *map, int cancel));
-static void aux_build PARAMS ((Side *side, Map *map, int cancel));
-static void impl_build PARAMS ((Side *side, Unit *unit, int u2, int n));
-static void aux_distance PARAMS ((Side *side, Map *map, int cancel));
-static void aux_fire_at PARAMS ((Side *side, Map *map, int cancel));
-static void aux_give_unit PARAMS ((Side *side, Map *map, int cancel));
-static void aux_move_look PARAMS ((Side *side, Map *map));
-static void aux_move_dir PARAMS ((Side *side, Map *map, Unit *unit));
-static void aux_message PARAMS ((Side *side, Map *map, int cancel));
-static void aux_move_to PARAMS ((Side *side, Map *map, int cancel));
-static void aux_name PARAMS ((Side *side, Map *map, int cancel));
-static void aux_others PARAMS ((Side *side, Map *map, int cancel));
-static void aux_remove_terrain PARAMS ((Side *side, Map *map, int cancel));
-static void aux_remove_terrain_2 PARAMS ((Side *side, Map *map, int cancel));
-static void do_remove_terrain_2 PARAMS ((Side *side, Map *map, int t));
-static void aux_resign PARAMS ((Side *side, Map *map, int cancel));
-static void aux_resign_2 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_leave_game PARAMS ((Side *side, Map *map, int cancel));
-static void aux_kill_game PARAMS ((Side *side, Map *map, int cancel));
-static void aux_resign_b PARAMS ((Side *side, Map *map, int cancel));
-static void aux_save_2 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_save_1 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_save_1_1 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_set_formation PARAMS ((Side *side, Map *map, int cancel));
-static void save_the_game PARAMS ((Side *side));
+static void aux_add_terrain(Side *side, Map *map, int cancel);
+static void aux_add_terrain_2(Side *side, Map *map, int cancel);
+static void do_add_terrain_2(Side *side, Map *map, int t);
+static void aux_attack(Side *side, Map *map, int cancel);
+static void aux_build(Side *side, Map *map, int cancel);
+static void impl_build(Side *side, Unit *unit, int u2, int n);
+static void aux_distance(Side *side, Map *map, int cancel);
+static void aux_fire_at(Side *side, Map *map, int cancel);
+static void aux_give_unit(Side *side, Map *map, int cancel);
+static void aux_move_look(Side *side, Map *map);
+static void aux_move_dir(Side *side, Map *map, Unit *unit);
+static void aux_message(Side *side, Map *map, int cancel);
+static void aux_move_to(Side *side, Map *map, int cancel);
+static void aux_name(Side *side, Map *map, int cancel);
+static void aux_others(Side *side, Map *map, int cancel);
+static void aux_remove_terrain(Side *side, Map *map, int cancel);
+static void aux_remove_terrain_2(Side *side, Map *map, int cancel);
+static void do_remove_terrain_2(Side *side, Map *map, int t);
+static void aux_resign(Side *side, Map *map, int cancel);
+static void aux_resign_2(Side *side, Map *map, int cancel);
+static void aux_leave_game(Side *side, Map *map, int cancel);
+static void aux_kill_game(Side *side, Map *map, int cancel);
+static void aux_resign_b(Side *side, Map *map, int cancel);
+static void aux_save_2(Side *side, Map *map, int cancel);
+static void aux_save_1(Side *side, Map *map, int cancel);
+static void aux_save_1_1(Side *side, Map *map, int cancel);
+static void aux_set_formation(Side *side, Map *map, int cancel);
+static void save_the_game(Side *side);
 
-static void aux_design PARAMS ((Side *side, Map *map, int cancel));
+static void aux_design(Side *side, Map *map, int cancel);
 
 /* Use this macro in any command if it requires a current unit. */
 
-#define REQUIRE_UNIT(side, map)  \
-  if (!in_play((map)->curunit)) {  \
+#define REQUIRE_UNIT(map)  \
+  if (!in_play((map)->curunit) || (map)->curunit_id != (map)->curunit->id) {  \
     (map)->curunit = NULL;  \
-    cmd_error((side), "No current unit to command!");  \
+    (map)->curunit_id = 0;  \
+    cmd_error((dside), "No current unit to command!");  \
     return;  \
   }
 
@@ -57,14 +58,13 @@ int designed_on = FALSE;
 /* Definitions of all the command functions. */
 
 void
-do_add_terrain(side)
-Side *side;
+do_add_terrain(Side *side)
 {
     Map *map = side->ui->curmap;
     int u, t, numtypes, tfirst = NONTTYPE, possibles[MAXTTYPES];
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     u = unit->type;
     numtypes = 0;
     for_all_terrain_types(t) {
@@ -169,13 +169,12 @@ int cancel;
 }
 
 void
-do_attack(side)
-Side *side;
+do_attack(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
     
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     map->argunitid = unit->id;
     ask_position(side, map, "Attack where?", aux_attack);
 }
@@ -213,13 +212,12 @@ int cancel;
 }
 
 void
-do_auto(side)
-Side *side;
+do_auto(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
     
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     if (unit->plan) {
 	net_set_unit_ai_control(side, unit, !unit->plan->aicontrol, FALSE);
 	/* a hack */
@@ -228,14 +226,13 @@ Side *side;
 }
 
 void
-do_build(side)
-Side *side;
+do_build(Side *side)
 {
     Map *map = side->ui->curmap;
     int u, u2, possibles[MAXUTYPES], numtypes, ufirst = NONUTYPE;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     u = unit->type;
     if (!can_build(unit)) {
 	cmd_error(side, "%s can't build anything!", unit_handle(side, unit));
@@ -324,19 +321,17 @@ int u2, n;
 }
 
 void
-do_clear_plan(side)
-Side *side;
+do_clear_plan(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     net_set_unit_plan_type(side, unit, PLAN_NONE);
 }
 
 void
-do_collect(side)
-Side *side;
+do_collect(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
@@ -364,15 +359,13 @@ Side *side;
 }
 
 void
-do_copying(side)
-Side *side;
+do_copying(Side *side)
 {
     popup_help(side, copying_help_node);
 }
 
 void
-do_delay(side)
-Side *side;
+do_delay(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
@@ -391,14 +384,13 @@ Side *side;
 }
 
 void
-do_detach(side)
-Side *side;
+do_detach(Side *side)
 {
     Map *map = side->ui->curmap;
     int rslt;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     if (!completed(unit)) {
 	cmd_error(side, "%s is incomplete; cannot detach",
 		  unit_handle(side, unit));
@@ -413,14 +405,13 @@ Side *side;
 }
 
 void
-do_detonate(side)
-Side *side;
+do_detonate(Side *side)
 {
     Map *map = side->ui->curmap;
     int rslt;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     rslt = check_detonate_action(unit, unit, unit->x, unit->y, unit->z);
     if (valid(rslt)) {
 	net_prep_detonate_action(unit, unit, unit->x, unit->y, unit->z);
@@ -430,22 +421,20 @@ Side *side;
 }
 
 void
-do_dir(side)
-Side *side;
+do_dir(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     aux_move_dir(side, map, map->curunit);
 }
 
 void
-do_dir_multiple(side)
-Side *side;
+do_dir_multiple(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     map->prefixarg = 9999;
     aux_move_dir(side, map, map->curunit);
 }
@@ -484,24 +473,22 @@ Unit *unit;
 /* Get rid of a unit. */
 
 void
-do_disband(side)
-Side *side;
+do_disband(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     net_disband_unit(side, unit);
 }
 
 void
-do_disembark(side)
-Side *side;
+do_disembark(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit, *transport;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     transport = unit->transport;
     if (transport == NULL) {
 	cmd_error(side, "Not in a transport");
@@ -529,12 +516,11 @@ Side *side;
 }
 
 void
-do_distance(side)
-Side *side;
+do_distance(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     map->argunitid = map->curunit->id;
     ask_position(side, map, "Distance to where?", aux_distance);
 }
@@ -570,14 +556,13 @@ int cancel;
 }
 
 void
-do_embark(side)
-Side *side;
+do_embark(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *transport, *occ;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     /* look for the first possible transport */
     for_all_stack(unit->x, unit->y, transport) {
 	/* make sure its not the transport we're in and we can enter it */
@@ -600,21 +585,19 @@ Side *side;
 }
 
 void
-do_escape(side)
-Side *side;
+do_escape(Side *side)
 {
 }
 
 void
-do_fire(side)
-Side *side;
+do_fire(Side *side)
 {
     Map *map = side->ui->curmap;
     int sx, sy, x, y, rslt;
     Unit *other;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
 
 #if 0
     if (map->frombutton) {
@@ -690,14 +673,13 @@ int cancel;
 }
 
 void
-do_fire_into(side)
-Side *side;
+do_fire_into(Side *side)
 {
     Map *map = side->ui->curmap;
     int x = map->inpx, y = map->inpy, rslt;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
 
     if (inside_area(x, y)) {
 	if (x != unit->x || y != unit->y) {
@@ -714,8 +696,7 @@ Side *side;
 }
 
 void
-do_flash(side)
-Side *side;
+do_flash(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
@@ -723,8 +704,7 @@ Side *side;
 /* Toggle the "follow-action" flag. */
 
 void
-do_follow_action(side)
-Side *side;
+do_follow_action(Side *side)
 {
     Map *map = side->ui->curmap;
     
@@ -737,8 +717,7 @@ Side *side;
 }
 
 void
-do_give(side)
-Side *side;
+do_give(Side *side)
 {
     Map *map = side->ui->curmap;
     int something = FALSE;
@@ -750,7 +729,7 @@ Side *side;
 	cmd_error(side, "No materials in this game!");
 	return;
     }
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     u = unit->type;
     main = unit->transport;
     if (main == NULL) {
@@ -790,7 +769,7 @@ do_give_unit(Side *side)
     Unit *unit = map->curunit;
     Side *side2;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     if (between(0, map->prefixarg, numsides)) {
 	side2 = side_n(map->prefixarg);
 	really_do_give_unit(map->curunit, side2);
@@ -852,7 +831,7 @@ do_idle(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     if (map->prefixarg < 0)
       map->prefixarg = 9999;
     net_set_sentry_task(unit, map->prefixarg);
@@ -933,6 +912,9 @@ do_map(Side *side)
     } else if (strcmp(cmdargstr, "temperature") == 0) {
 	vp->draw_temperature = !vp->draw_temperature;
 	redraw_map(map);
+    } else if (strcmp(cmdargstr, "transitions") == 0) {
+	toggle_mapw_transitions(map);
+	redraw_map(map);
     } else if (strcmp(cmdargstr, "tstyle-solid") == 0) {
 	map->terrain_style = 0;
 	redraw_map(map);
@@ -964,10 +946,7 @@ do_map(Side *side)
 	vp->draw_winds = !vp->draw_winds;
 	redraw_map(map);
     } else if (*cmdargstr == '!') {
-	char tclbuf[500];
-
-	strcpy(tclbuf, cmdargstr + 1);
-	Tcl_Eval(interp, tclbuf);
+	eval_tcl_cmd("%s", cmdargstr + 1);
     } else {
 	cmd_error(side, "Map command \"%s\" not recognized!", cmdargstr);
     }
@@ -977,8 +956,7 @@ do_map(Side *side)
    recognized specially, causing various actions. */
 
 void
-do_message(side)
-Side *side;
+do_message(Side *side)
 {
     Map *map = side->ui->curmap;
     char prompt[BUFSIZE];
@@ -1030,13 +1008,12 @@ int cancel;
 /* The command proper. */
 
 void
-do_move_to(side)
-Side *side;
+do_move_to(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     map->argunitid = unit->id;
     ask_position(side, map, "Move to where?", aux_move_to);
 }
@@ -1072,14 +1049,13 @@ int cancel;
 /* Name/rename the current unit. */
 
 void
-do_name(side)
-Side *side;
+do_name(Side *side)
 {
     Map *map = side->ui->curmap;
     char tmpbuf[BUFSIZE];
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     map->argunitid = unit->id;
     sprintf(tmpbuf, "New name for %s:", unit_handle(side, unit));
     ask_string(side, map, tmpbuf, unit->name, aux_name);
@@ -1112,8 +1088,7 @@ int cancel;
 /* (should clone last map in list perhaps?) */
 
 void
-do_new_map(side)
-Side *side;
+do_new_map(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
@@ -1125,14 +1100,13 @@ Side *side;
    all at once. */
 
 void
-do_occupant(side)
-Side *side;
+do_occupant(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *nextocc;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     nextocc = find_next_occupant(unit);
     if (nextocc != unit) {
 	set_current_unit(map, nextocc);
@@ -1140,15 +1114,13 @@ Side *side;
 }
 
 void
-do_orders_popup(side)
-Side *side;
+do_orders_popup(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_other(side)
-Side *side;
+do_other(Side *side)
 {
     Map *map = side->ui->curmap;
 
@@ -1184,22 +1156,19 @@ int cancel;
 }
 
 void
-do_print_view(side)
-Side *side;
+do_print_view(Side *side)
 {  
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_produce(side)
-Side *side;
+do_produce(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_quit(side)
-Side *side;
+do_quit(Side *side)
 {
     Map *map = side->ui->curmap;
 
@@ -1302,20 +1271,18 @@ int cancel;
 /* Center the screen on the current location. */
 
 void
-do_recenter(side)
-Side *side;
+do_recenter(Side *side)
 {
-    Map *map = side->ui->curmap;
+    Map *map = dside->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
-    recenter(side, map, map->curunit->x, map->curunit->y);
+    REQUIRE_UNIT(map);
+    recenter(map, map->curunit->x, map->curunit->y);
 }
 
 /* Redraw everything using the same code as when windows need a redraw. */
 
 void
-do_refresh(side)
-Side *side;
+do_refresh(Side *side)
 {
     Map *map;
 
@@ -1325,14 +1292,13 @@ Side *side;
 }
 
 void
-do_remove_terrain(side)
-Side *side;
+do_remove_terrain(Side *side)
 {
     Map *map = side->ui->curmap;
     int u, t, numtypes, tfirst = NONTTYPE, possibles[MAXTTYPES];
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     u = unit->type;
     numtypes = 0;
     for_all_terrain_types(t) {
@@ -1435,13 +1401,12 @@ int cancel;
 }
 
 void
-do_repair(side)
-Side *side;
+do_repair(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit, *other;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     unit = map->curunit;
     if (valid(check_repair_action(unit, unit, unit))) {
 	net_prep_repair_action(unit, unit, unit);
@@ -1457,18 +1422,16 @@ Side *side;
 }
 
 void
-do_reserve(side)
-Side *side;
+do_reserve(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     net_set_unit_reserve(side, map->curunit, TRUE, TRUE /* is this right??? */);
 }
 
 void
-do_resign(side)
-Side *side;
+do_resign(Side *side)
 {
     Map *map = side->ui->curmap;
 
@@ -1503,13 +1466,12 @@ int cancel;
 /* (should warn if task is likely to fail) */
 
 void
-do_return(side)
-Side *side;
+do_return(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     /* (should doublecheck range and error out if no chance) */
     if (in_play(unit)) {
 	net_set_resupply_task(unit, NONMTYPE);
@@ -1525,27 +1487,13 @@ Side *side;
    saving as much game state as possible, for resumption later. */
 
 void
-do_save(side)
-Side *side;
+do_save(Side *side)
 {
     Map *map = side->ui->curmap;
-    Side *side2;
 
-    /* First check to see if anybody is in the middle of doing something
-       (like renaming a unit) whose state would be lost. */
-    for_all_sides(side2) {
-	if (side2 != side && side2->busy) {
-	    cmd_error(side, "The %s are busy, can't save right now.",
-		      plural_form(side2->name));
-	}
-    }
 #ifdef DESIGNERS
     if (side->designer) {
 	eval_tcl_cmd("popup_designer_save");
-#if 0
-	ask_string(side, map, "Types of data to save?", "all",
-		   aux_save_1);
-#endif
 	return;
     }
 #endif /* DESIGNERS */
@@ -1559,10 +1507,7 @@ Side *side;
 /* Make a module appropriate to a save file, write the file, and leave. */
 
 static void
-aux_save_2(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_save_2(Side *side, Map *map, int cancel)
 {
     if (cancel)
       return;
@@ -1572,11 +1517,11 @@ int cancel;
 }
 
 static void
-save_the_game(side)
-Side *side;
+save_the_game(Side *side)
 {
     char *savename = saved_game_filename();
 
+    /* (should use name in save dialog) */
     notify_all("Game will be saved to \"%s\" ...", savename);
     if (write_entire_game_state(savename)) {
 	close_displays();
@@ -1661,12 +1606,11 @@ int cancel;
 #endif /* DESIGNERS */
 
 void
-do_set_formation(side)
-Side *side;
+do_set_formation(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     map->argunitid = map->curunit->id;
     ask_position(side, map, "Form up on who?", aux_set_formation);
 }
@@ -1706,33 +1650,29 @@ int cancel;
 }
 
 void
-do_set_view_angle(side)
-Side *side;
+do_set_view_angle(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_side_closeup(side)
-Side *side;
+do_side_closeup(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_sleep(side)
-Side *side;
+do_sleep(Side *side)
 {
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     net_set_unit_asleep(side, unit, TRUE, TRUE /* is this right??? */);
 }
 
 void
-do_standing_orders(side)
-Side *side;
+do_standing_orders(Side *side)
 {
     Map *map = side->ui->curmap;
     int rslt;
@@ -1746,8 +1686,7 @@ Side *side;
 }
 
 void
-do_survey(side)
-Side *side;
+do_survey(Side *side)
 {
     Map *map = side->ui->curmap;
 
@@ -1779,8 +1718,7 @@ Side *side;
 /* Take supplies from transport. */
 
 void
-do_take(side)
-Side *side;
+do_take(Side *side)
 {
     Map *map = side->ui->curmap;
     short m, amts[MAXMTYPES], rslts[MAXMTYPES], needed;
@@ -1790,7 +1728,7 @@ Side *side;
 	cmd_error(side, "No materials in this game!");
 	return;
     }
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     for_all_material_types(m) {
 	amts[m] = map->prefixarg;
     }
@@ -1799,15 +1737,13 @@ Side *side;
 }
 
 void
-do_unit_closeup(side)
-Side *side;
+do_unit_closeup(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_up(side)
-Side *side;
+do_up(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
@@ -1815,20 +1751,18 @@ Side *side;
 /* Command to display the program version. */
 
 void
-do_version(side)
-Side *side;
+do_version(Side *side)
 {
     notify(side, "Xconq version %s", version_string());
     notify(side, "(c) %s", copyright_string());
 }
 
 void
-do_wake(side)
-Side *side;
+do_wake(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     /* Do the curunit explicitly, might only be an occupant. */
     if (in_play(map->curunit)) {
 	net_wake_unit(side, map->curunit, FALSE);
@@ -1841,12 +1775,11 @@ Side *side;
 }
 
 void
-do_wake_all(side)
-Side *side;
+do_wake_all(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    REQUIRE_UNIT(side, map);
+    REQUIRE_UNIT(map);
     /* Do the curunit explicitly, might only be an occupant. */
     if (in_play(map->curunit)) {
 	net_wake_unit(side, map->curunit, TRUE);
@@ -1859,8 +1792,7 @@ Side *side;
 }
 
 void
-do_warranty(side)
-Side *side;
+do_warranty(Side *side)
 {
     popup_help(side, warranty_help_node);
 }
@@ -1869,22 +1801,19 @@ Side *side;
    world at once). */
 
 void
-do_world_map(side)
-Side *side;
+do_world_map(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_zoom_in(side)
-Side *side;
+do_zoom_in(Side *side)
 {
     zoom_in_out(side, side->ui->curmap, 1);
 }
 
 void
-do_zoom_out(side)
-Side *side;
+do_zoom_out(Side *side)
 {
     zoom_in_out(side, side->ui->curmap, -1);
 }
@@ -1892,8 +1821,7 @@ Side *side;
 #ifdef DESIGNERS
 
 void
-do_design(side)
-Side *side;
+do_design(Side *side)
 {
     Map *map = side->ui->curmap;
 
@@ -1932,8 +1860,7 @@ int cancel;
 }
 
 void
-really_do_design(side)
-Side *side;
+really_do_design(Side *side)
 {
     int u;
     Map *map;
@@ -1953,15 +1880,13 @@ Side *side;
 #ifdef DEBUGGING
 
 void
-do_profile(side)
-Side *side;
+do_profile(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
 
 void
-do_trace(side)
-Side *side;
+do_trace(Side *side)
 {
     cmd_error(side, "Not implemented.");
 }
@@ -1971,25 +1896,14 @@ Side *side;
 /* Generic command error feedback. */
 
 void
-#ifdef ANSI_PROTOTYPES
 cmd_error(Side *side, char *fmt, ...)
-#else
-cmd_error(side, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-Side *side;
-char *fmt;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
-    if (!empty_string(fmt)) {
-#ifdef ANSI_PROTOTYPES
-	va_list ap;
+    va_list ap;
 
+    if (!empty_string(fmt)) {
 	va_start(ap, fmt);
 	vnotify(side, fmt, ap);
 	va_end(ap);
-#else
-	notify(side, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
     }
     /* Only beep once, even if a command generates multiple error messages. */
     if (side->ui->beepcount++ < 1)
