@@ -108,6 +108,7 @@ typedef struct a_ui {
     XColor *graycolor;		/* color for graying out (usually gray) */
     XColor *diffcolor;		/* unusual/distinct color (usually maroon) */
     XColor *badcolor;		/* color for non-OKness (usually red) */
+    XColor *warncolor;		/* color for warnings (usually yellow) */
     XColor *grid_color;
     XColor *unseen_color;
     XColor *contour_color;
@@ -184,6 +185,8 @@ typedef struct a_ui {
     Pixmap emblempics[MAXSIDES];
     Pixmap emblemmasks[MAXSIDES];
     int embw[MAXSIDES], embh[MAXSIDES];
+
+    ImageFamily *blastimages[3];
 #if 0
     /* Map legend drawing machinery */
     XFontStruct *ulegendfonts[NUMPOWERS][MAXUTYPES];
@@ -233,7 +236,7 @@ typedef struct a_map {
     short follow_action;	/* scroll to where something has occured */
 
     struct a_unit *curunit;	/* Unit under cursor */
-    struct a_unit *savedcurunit;/* Unit under cursor (saved) */
+    short curunit_id;
     void (*modalhandler) PARAMS ((Side *side, struct a_map *map, int cancelled));
     char inpch;			/* Keyboard char */
     short inpsx, inpsy;
@@ -268,7 +271,11 @@ extern Tcl_Interp *interp;
 
 extern Side *dside;
 
+extern void recenter(Map *map, int x, int y);
+extern void put_on_screen(Map *map, int x, int y);
+extern int in_middle(Map *map, int x, int y);
+
 extern void redraw_map(Map *map);
 extern VP *widget_vp(Map *map);
 
-
+extern void eval_tcl_cmd(char *fmt, ...);
