@@ -1,5 +1,5 @@
 /* Initialization for the tcl/tk interface to Xconq.
-   Copyright (C) 1998 Stanley T. Shebs.
+   Copyright (C) 1998, 1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@ void init_emblem(Side *side2);
 void abort ();
 #endif
 
+Pixmap tranpics[NUMPOWERS];
 Pixmap bordpics[NUMPOWERS];
 Pixmap connpics[NUMPOWERS];
 Pixmap windpics[5][NUMDIRS];
@@ -80,15 +81,10 @@ int min_h_for_unit_image = 16;
 #include "bitmaps/buildcurs.b"
 #include "bitmaps/buildmask.b"
 
-#if 0
-#include "bitmaps/bomb1.b"
-#include "bitmaps/bomb2.b"
-#include "bitmaps/bomb3.b"
-#include "bitmaps/bomb4.b"
-
 #include "bitmaps/closer.b"
 #include "bitmaps/farther.b"
 
+#if 0
 #include "bitmaps/gray.b"
 #include "bitmaps/darkgray.b"
 #endif
@@ -100,6 +96,9 @@ int min_h_for_unit_image = 16;
 #include "bitmaps/hex64.b"
 #include "bitmaps/hex64b.b"
 
+#include "bitmaps/tran16.b"
+#include "bitmaps/tran32.b"
+
 #include "bitmaps/bord16.b"
 #include "bitmaps/bord32.b"
 #include "bitmaps/bord64.b"
@@ -141,6 +140,8 @@ int min_h_for_unit_image = 16;
 #include "bitmaps/dots.b"
 #include "bitmaps/ants.b"
 
+#include "bitmaps/laurels.b"
+
 #ifdef DESIGNERS
 #include "bitmaps/curscell.b"
 #include "bitmaps/curscellm.b"
@@ -240,12 +241,14 @@ init_display()
     init_unit_images();
     init_terrain_images();
     init_emblem_images();
+    init_other_images();
     tmp_valid = FALSE;
     report_missing_images();
     imf_describe_hook = tk_describe_image;
     set_optional_colors();
     init_bitmaps();
     init_cursors();
+    update_view_controls_info();
 
     /* Create the generic windows. */
     dside->ui->maps = NULL;
@@ -278,6 +281,7 @@ set_colors()
     dside->ui->diffcolor = dside->ui->blackcolor;
     dside->ui->graycolor = dside->ui->whitecolor;
     dside->ui->badcolor = dside->ui->whitecolor;
+    dside->ui->warncolor = dside->ui->whitecolor;
     dside->ui->grid_color = dside->ui->fgcolor;
     dside->ui->unseen_color = dside->ui->fgcolor;
     dside->ui->contour_color = dside->ui->fgcolor;
@@ -324,6 +328,8 @@ set_optional_colors()
 	  dside->ui->unit_name_color = color;
 	if ((color = request_color("red")) != NULL)
 	  dside->ui->badcolor = color;
+	if ((color = request_color("yellow")) != NULL)
+	  dside->ui->warncolor = color;
     }
 }
 
@@ -541,6 +547,16 @@ init_bitmaps()
     dside->ui->bhexpics[6] =
       Tk_GetBitmap(interp, rootwin, Tk_GetUid("hex64b"));
 
+    Tk_DefineBitmap(interp, Tk_GetUid("tran16"),
+		    tran16_bits, tran16_width, tran16_height);
+    tranpics[4] =
+      Tk_GetBitmap(interp, rootwin, Tk_GetUid("tran16"));
+    Tk_DefineBitmap(interp, Tk_GetUid("tran32"),
+		    tran32_bits, tran32_width, tran32_height);
+    tranpics[5] =
+      Tk_GetBitmap(interp, rootwin, Tk_GetUid("tran32"));
+
+
     Tk_DefineBitmap(interp, Tk_GetUid("bord16"),
 		    bord16_bits, bord16_width, bord16_height);
     bordpics[4] =
@@ -642,17 +658,6 @@ init_bitmaps()
     windpics[4][NORTHWEST] = Tk_GetBitmap(interp, rootwin, Tk_GetUid("wind4nw"));
 
 
-#if 0
-    /* Get pictures of mushroom clouds. */
-    dside->ui->bombpics[0] =
-      XCreateBitmapFromData(dpy, win, bomb1_bits, bomb1_width, bomb1_height);
-    dside->ui->bombpics[1] =
-      XCreateBitmapFromData(dpy, win, bomb2_bits, bomb2_width, bomb2_height);
-    dside->ui->bombpics[2] =
-      XCreateBitmapFromData(dpy, win, bomb3_bits, bomb3_width, bomb3_height);
-    dside->ui->bombpics[3] =
-      XCreateBitmapFromData(dpy, win, bomb4_bits, bomb4_width, bomb4_height);
-#endif
     Tk_DefineBitmap(interp, Tk_GetUid("miss"),
 		    miss_bits, miss_width, miss_height);
     dside->ui->hitpics[0] =
@@ -676,6 +681,20 @@ init_bitmaps()
     Tk_DefineBitmap(interp, Tk_GetUid("ants"),
 		    ants_bits, ants_width, ants_height);
     antpic = Tk_GetBitmap(interp, rootwin, Tk_GetUid("ants"));
+    /* These bitmaps are used only by tcl code, don't need to be assigned
+       to a C variable. */
+    Tk_DefineBitmap(interp, Tk_GetUid("shoot_cursor"),
+		    shootcursor_bits, shootcursor_width, shootcursor_height);
+    Tk_DefineBitmap(interp, Tk_GetUid("build"),
+		    buildcursor_bits, buildcursor_width, buildcursor_height);
+    Tk_DefineBitmap(interp, Tk_GetUid("looking_glass"),
+		    lookglass_bits, lookglass_width, lookglass_height);
+    Tk_DefineBitmap(interp, Tk_GetUid("closer"),
+		    closer_bits, closer_width, closer_height);
+    Tk_DefineBitmap(interp, Tk_GetUid("farther"),
+		    farther_bits, farther_width, farther_height);
+    Tk_DefineBitmap(interp, Tk_GetUid("laurels"),
+		    laurels_bits, laurels_width, laurels_height);
 }
 
 static void
@@ -822,12 +841,35 @@ init_emblem(Side *side2)
     dside->ui->eimages_loaded[s2] = TRUE;
 }
 
+init_other_images()
+{
+    ImageFamily *imf;
+    Tk_Window tkwin = Tk_MainWindow(interp);
+
+    tmp_root_window = tkwin;
+    tmp_valid = TRUE;
+    imf = get_generic_images(dside, "miss");
+    record_imf_get(imf);
+    if (DebugG)
+      describe_imf(dside, "blast", side_desig(dside), imf);
+    dside->ui->blastimages[0] = imf;
+    imf = get_generic_images(dside, "hit");
+    record_imf_get(imf);
+    if (DebugG)
+      describe_imf(dside, "blast", side_desig(dside), imf);
+    dside->ui->blastimages[1] = imf;
+    imf = get_generic_images(dside, "kill");
+    record_imf_get(imf);
+    if (DebugG)
+      describe_imf(dside, "blast", side_desig(dside), imf);
+    tmp_valid = FALSE;
+    dside->ui->blastimages[2] = imf;
+}
+
 /* Describe (for debugging) Tk-specific parts of an image. */
 
 static void
-tk_describe_image(side, img)
-Side *side;
-Image *img;
+tk_describe_image(Side *side, Image *img)
 {
     TkImage *tkimg;
 
@@ -836,3 +878,17 @@ Image *img;
       DGprintf(" (tk mono %d color %d mask %d solid %d)",
 	       tkimg->mono, tkimg->colr, tkimg->mask, tkimg->solid);
 }
+
+update_view_controls_info()
+{
+    eval_tcl_cmd("update_view_controls_info %d %d %d %d %d %d %d %d %d",
+		 all_see_all,
+		 dside->may_set_see_all,
+		 people_sides_defined(),
+		 control_sides_defined(),
+		 elevations_defined(),
+		 (world.daylength != 1),
+		 temperatures_defined(),
+		 winds_defined(),
+		 clouds_defined());
+}
