@@ -59,8 +59,9 @@ typedef struct {
     Tk_3DBorder bg_border;	/* Used for drawing background. */
     int relief;			/* Indicates whether window as a whole is
 				 * raised, sunken, or flat. */
-    GC gc;			/* Graphics context for copying from
+    GC copygc;			/* Graphics context for copying from
 				 * off-screen pixmap onto screen. */
+    GC gc;
     int double_buffer;		/* Non-zero means double-buffer redisplay
 				 * with pixmap;  zero means draw straight
 				 * onto the display. */
@@ -72,6 +73,8 @@ typedef struct {
     int show_color;
     int show_names;
     int show_masks;
+    int show_bbox;
+    int show_solid;
 
     int width, height;
 
@@ -81,13 +84,15 @@ typedef struct {
     int numimages;
     ImageFamily **imf_list;
 
-    ImageFamily *fill_tile;
-    ImageFamily *all_emblem;
-
     int selected;
+    int with_terrain;
+    int with_emblem;
 
     int eltw, elth;
-    int cols;
+    int rows, cols;
+
+    int numvisrows;
+    int firstvisrow;
 
 } Imfsample;
 
@@ -118,12 +123,16 @@ static Tk_ConfigSpec config_specs[] = {
 	"0", Tk_Offset(Imfsample, pad), 0},
     {TK_CONFIG_RELIEF, "-relief", "relief", "Relief",
 	"raised", Tk_Offset(Imfsample, relief), 0},
+    {TK_CONFIG_INT, "-showbbox", "showBBox", "ShowBBox",
+	"0", Tk_Offset(Imfsample, show_bbox), 0},
     {TK_CONFIG_INT, "-showcolor", "showColor", "ShowColor",
 	"1", Tk_Offset(Imfsample, show_color), 0},
     {TK_CONFIG_INT, "-shownames", "showNames", "ShowNames",
 	"1", Tk_Offset(Imfsample, show_names), 0},
     {TK_CONFIG_INT, "-showmasks", "showMasks", "ShowMasks",
 	"1", Tk_Offset(Imfsample, show_masks), 0},
+    {TK_CONFIG_INT, "-showsolid", "showSolid", "ShowSolid",
+	"0", Tk_Offset(Imfsample, show_solid), 0},
     {TK_CONFIG_COLOR, "-fillcolor", "fillColor", "FillColor",
 	"gray", Tk_Offset(Imfsample, fill_color), 0},
     {TK_CONFIG_PIXELS, "-width", "width", "Width",
@@ -132,16 +141,16 @@ static Tk_ConfigSpec config_specs[] = {
 	(char *) NULL, 0, 0}
 };
 
-static void imfsample_cmd_deleted_proc PARAMS ((ClientData cldata));
-static int imfsample_configure PARAMS ((Tcl_Interp *interp, Imfsample *imfsample,
-				      int argc, char **argv, int flags));
-static void imfsample_destroy PARAMS ((char *memPtr));
-static void imfsample_display PARAMS ((ClientData cldata));
-static void imfsample_event_proc PARAMS ((ClientData cldata,
-					XEvent *eventPtr));
-static int imfsample_widget_cmd PARAMS ((ClientData cldata,
-				     Tcl_Interp *interp,
-				     int argc, char **argv));
+static void imfsample_cmd_deleted_proc(ClientData cldata);
+static int imfsample_configure(Tcl_Interp *interp, Imfsample *imfsample,
+			       int argc, char **argv, int flags);
+static void imfsample_destroy(char *memPtr);
+static void imfsample_display(ClientData cldata);
+static void imfsample_event_proc(ClientData cldata, XEvent *eventPtr);
+static int imfsample_widget_cmd(ClientData cldata, Tcl_Interp *interp,
+				int argc, char **argv);
+
+/* The command to create an image sample window. */
 
 int
 imfsample_cmd(cldata, interp, argc, argv)
@@ -179,6 +188,7 @@ char **argv;
     imfsample->border_width = 0;
     imfsample->bg_border = NULL;
     imfsample->relief = TK_RELIEF_FLAT;
+    imfsample->copygc = None;
     imfsample->gc = None;
     imfsample->double_buffer = 1;
     imfsample->update_pending = 0;
@@ -187,11 +197,15 @@ char **argv;
     imfsample->show_masks = 0;
     imfsample->fill_color = NULL;
     imfsample->selected = -1;
+    imfsample->with_terrain = -1;
+    imfsample->with_emblem = -1;
 
     imfsample->main_imf_name = "";
     imfsample->numimages = 0;
     imfsample->imf_list =
       (ImageFamily **) xmalloc(MAXFAMS * sizeof(ImageFamily *));
+    imfsample->numvisrows = 0;
+    imfsample->firstvisrow = 0;
 
     Tk_CreateEventHandler(imfsample->tkwin, ExposureMask|StructureNotifyMask,
 			  imfsample_event_proc, (ClientData) imfsample);
@@ -215,6 +229,7 @@ char **argv;
     int result = TCL_OK;
     size_t length;
     char c;
+    int x, y, col, row, n;
 
     if (argc < 2) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"",
@@ -253,7 +268,13 @@ char **argv;
 	       && (length >= 2)) {
 	if (strcmp(argv[2], "imf") == 0) {
 	    imfsample_add_imf(imfsample, argv[3]);
+	} else if (strcmp(argv[2], "all") == 0) {
+	    imfsample_add_imf(imfsample, "-all");
 	}
+    } else if ((c == 'e') && (strncmp(argv[1], "emblem", length) == 0)
+	       && (length >= 2)) {
+	n = strtol(argv[2], NULL, 10);
+	imfsample->with_emblem = n;
     } else if ((c == 'r') && (strncmp(argv[1], "replace", length) == 0)
 	       && (length >= 2)) {
 	if (strcmp(argv[2], "imf") == 0) {
@@ -263,25 +284,53 @@ char **argv;
 	       && (length >= 2)) {
 	if (strcmp(argv[2], "imf") == 0) {
 	    imfsample_remove_imf(imfsample, argv[3]);
+	} else if (strcmp(argv[2], "all") == 0) {
+	    imfsample_remove_imf(imfsample, argv[3]);
 	}
     } else if ((c == 's') && (strncmp(argv[1], "select", length) == 0)
 	       && (length >= 2)) {
-	int x, y, col, row, n;
-	int firstvisrow = 0;
-
 	x = strtol(argv[2], NULL, 10);
 	y = strtol(argv[3], NULL, 10);
 	col = x / imfsample->eltw;
-	row = y / imfsample->elth + firstvisrow;
+	row = y / imfsample->elth + imfsample->firstvisrow;
 	n = row * imfsample->cols + col;
 	if (n < 0 || n >= imfsample->numimages)
 	  n = -1;
 	imfsample->selected = n;
+    } else if ((c == 't') && (strncmp(argv[1], "terrain", length) == 0)
+	       && (length >= 2)) {
+	n = strtol(argv[2], NULL, 10);
+	imfsample->with_terrain = n;
     } else if ((c == 'x') && (strncmp(argv[1], "xview", length) == 0)) {
     } else if ((c == 'y') && (strncmp(argv[1], "yview", length) == 0)) {
+	int count, type, nrow = imfsample->firstvisrow;
+	double fraction, fraction2;
+
+	if (argc == 2) {
+	    fraction = 0;
+	    fraction2 = 1;
+	    printf("imfsample yview %g %g\n", fraction, fraction2);
+	    sprintf(interp->result, "%g %g", fraction, fraction2);
+	} else {
+	    type = Tk_GetScrollInfo(interp, argc, argv, &fraction, &count);
+	    switch (type) {
+	      case TK_SCROLL_ERROR:
+		goto error;
+	      case TK_SCROLL_MOVETO:
+		/*		nsy = ((mapw->vp->symax - mapw->vp->symin) * fraction); */
+		break;
+	      case TK_SCROLL_PAGES:
+		nrow += (count * imfsample->numvisrows * 4) / 5;
+		break;
+	      case TK_SCROLL_UNITS:
+		nrow += count;
+		break;
+	    }
+	    imfsample->firstvisrow = nrow;
+	}
     } else {
 	Tcl_AppendResult(interp, "bad option \"", argv[1],
-		"\": must be cget, configure, position, or size",
+		"\": must be cget, configure, position, replace, remove, select",
 		(char *) NULL);
 	goto error;
     }
@@ -304,6 +353,13 @@ char *imfname;
     int i;
     ImageFamily *imf = NULL;
 
+    if (strcmp(imfname, "-all") == 0) {
+	imfsample->numimages = 0;
+	for (i = 0; i < numimages; ++i) {
+	    imfsample->imf_list[imfsample->numimages++] = images[i];
+	}
+	return;
+    }
     imf = hack_find_imf(imfname);
     if (imf == NULL) {
 	fprintf(stderr, "Missing imf %s\n", imfname);
@@ -356,13 +412,20 @@ int flags;
        for use during redisplay.  */
     Tk_SetWindowBackground(imfsample->tkwin,
 			   Tk_3DBorderColor(imfsample->bg_border)->pixel);
-    if ((imfsample->gc == None) && imfsample->double_buffer) {
+    if ((imfsample->copygc == None) && 1/*imfsample->double_buffer*/) {
 	XGCValues gcValues;
 
 	gcValues.function = GXcopy;
 	gcValues.graphics_exposures = False;
-	imfsample->gc = Tk_GetGC(imfsample->tkwin,
-				  GCFunction|GCGraphicsExposures, &gcValues);
+	imfsample->copygc = XCreateGC(imfsample->display,
+				      DefaultRootWindow(imfsample->display),
+				      GCFunction|GCGraphicsExposures,
+				      &gcValues);
+    }
+    if (imfsample->gc == None) {
+	imfsample->gc = XCreateGC(imfsample->display,
+				  DefaultRootWindow(imfsample->display),
+				  None, NULL);
     }
 
     /* Register the desired geometry for the window, then arrange for
@@ -425,7 +488,6 @@ imfsample_display(ClientData cldata)
 {
     char *str;
     int rows, row, col, namex, namey, i, n, sx, sy;
-    int firstvisrow = 0, numvisrows;
     Imfsample *imfsample = (Imfsample *) cldata;
     Display *dpy = imfsample->display;
     Tk_Window tkwin = imfsample->tkwin;
@@ -452,15 +514,32 @@ imfsample_display(ClientData cldata)
     if (white_color == NULL)
       white_color = Tk_GetColor(interp, tkwin, Tk_GetUid("white"));
     /* Collect GC and font for subsequent work. */
-    gc = Tk_GetGC(imfsample->tkwin, None, NULL);
+    gc = imfsample->gc;
     XSetClipMask(dpy, gc, None);
     if (imfsample->show_names)
       tkfont = Tk_GetFont(interp, tkwin, "system");
 
-    /* Redraw the widget's background and border. */
-    Tk_Fill3DRectangle(tkwin, d, imfsample->bg_border, 0, 0, Tk_Width(tkwin),
-		       Tk_Height(tkwin), imfsample->border_width, imfsample->relief);
+    /* Redraw the widget's background/border. */
+    if (imfsample->with_terrain >= 0) {
+	ImageFamily *timf = imfsample->imf_list[imfsample->with_terrain];
+	Image *timg;
+	TkImage *tkimg;
 
+	timg = best_image(timf, 64, 64);
+	if (timg != NULL) {
+	    tkimg = (TkImage *) timg->hook;
+	    if (tkimg != NULL) {
+		XSetFillStyle(dpy, gc, FillTiled);
+		XSetTile(dpy, gc, tkimg->colr);
+		XFillRectangle(dpy, d, gc, 0, 0,
+			       Tk_Width(tkwin), Tk_Height(tkwin));
+	    }
+	}
+    } else {
+	Tk_Fill3DRectangle(tkwin, d, imfsample->bg_border, 0, 0,
+			   Tk_Width(tkwin), Tk_Height(tkwin),
+			   imfsample->border_width, imfsample->relief);
+    }
 #if 0
     for (i = 0; i < imfsample->numimages; i++) {
 	if (imf_interp_hook)
@@ -495,60 +574,60 @@ imfsample_display(ClientData cldata)
        width. */
     if (imfsample->show_names)
       imfsample->eltw = (winwidth - 10) / imfsample->cols;
-    rows = imfsample->numimages / imfsample->cols;
+    imfsample->rows = imfsample->numimages / imfsample->cols;
     /* Account for a last partial row. */
-    if (rows * imfsample->cols < imfsample->numimages)
-      ++rows;
+    if (imfsample->rows * imfsample->cols < imfsample->numimages)
+      ++(imfsample->rows);
     /* Compute the number of visible rows.  It would be time-consuming
        to render all the images, so try to do only the visible ones. */
-    numvisrows = winheight / imfsample->elth;
-    if (numvisrows > rows)
-      numvisrows = rows;
-    if (numvisrows < 1)
-      numvisrows = min(1, rows);
-    if (firstvisrow + numvisrows > rows)
-      firstvisrow = rows - numvisrows;
+    imfsample->numvisrows = winheight / imfsample->elth;
+    if (imfsample->numvisrows > imfsample->rows)
+      imfsample->numvisrows = imfsample->rows;
+    if (imfsample->numvisrows < 1)
+      imfsample->numvisrows = min(1, imfsample->rows);
+    if (imfsample->firstvisrow + imfsample->numvisrows > imfsample->rows)
+      imfsample->firstvisrow = imfsample->rows - imfsample->numvisrows;
     /* Now iterate through all the images we want to draw. */
-    for (row = firstvisrow; row < (firstvisrow + numvisrows); ++row) {
+    for (row = imfsample->firstvisrow; row < (imfsample->firstvisrow + imfsample->numvisrows); ++row) {
 	for (col = 0; col < imfsample->cols; ++col) {
 	    n = row * imfsample->cols + col;
 	    if (n >= imfsample->numimages)
 	      break;
-	    sx = col * imfsample->eltw + imfsample->pad;
-	    sy = (row - firstvisrow) * imfsample->elth + imfsample->pad;
-	    draw_one_image(imfsample, d, gc, imfsample->imf_list[n], sx, sy,
+	    sx = col * imfsample->eltw;
+	    sy = (row - imfsample->firstvisrow) * imfsample->elth;
+	    draw_one_image(imfsample, d, gc, imfsample->imf_list[n],
+			   sx + imfsample->pad, sy + imfsample->pad,
 			   imfsample->iwidth, imfsample->iheight);
 	    if (imfsample->show_names) {
-		namex = col * imfsample->eltw
-		  + imfsample->iwidth + imfsample->pad + 2;
-		namey = (row - firstvisrow) * imfsample->elth
-		  + (imfsample->elth / 2) + 5;
+		namex = sx + imfsample->pad + imfsample->iwidth + 2;
+		namey = sy + (imfsample->elth / 2) + 5;
 		XSetClipMask(dpy, gc, None);
 		XSetFillStyle(dpy, gc, FillSolid);
-		str = images[n]->name;
 		/* Draw the text in black only. */
 		/* (should invent a way to make show up when black bg; an
 		   offset version in white is semi-OK, but hard on eyes) */
 		XSetForeground(dpy, gc, black_color->pixel);
+		str = imfsample->imf_list[n]->name;
 		Tk_DrawChars(dpy, d, gc, tkfont, str, strlen(str),
 			     namex, namey);
 	    }
 	    /* Indicate the selected imf. */
 	    if (n == imfsample->selected) {
 		XSetClipMask(dpy, gc, None);
+		XSetFillStyle(dpy, gc, FillSolid);
 		XSetForeground(dpy, gc, black_color->pixel);
-		XDrawRectangle(dpy, d, gc, col * imfsample->eltw, (row - firstvisrow) * imfsample->elth, imfsample->eltw, imfsample->elth);
+		XDrawRectangle(dpy, d, gc, sx, sy,
+			       imfsample->eltw, imfsample->elth);
 	    }
 	}
     }
     /* If double-buffered, copy to the screen and release the pixmap.  */
     if (imfsample->double_buffer) {
-	XCopyArea(imfsample->display, pm, Tk_WindowId(tkwin), imfsample->gc,
-		  0, 0, (unsigned) winwidth, (unsigned) winheight,
-		  0, 0);
+	XCopyArea(imfsample->display, pm, Tk_WindowId(tkwin),
+		  imfsample->copygc,
+		  0, 0, (unsigned) winwidth, (unsigned) winheight, 0, 0);
 	Tk_FreePixmap(imfsample->display, pm);
     }
-    Tk_FreeGC(imfsample->display, gc);
     if (imfsample->show_names)
       Tk_FreeFont(tkfont);
 }
@@ -559,8 +638,10 @@ imfsample_destroy(char *ptr)
     Imfsample *imfsample = (Imfsample *) ptr;
 
     Tk_FreeOptions(config_specs, (char *) imfsample, imfsample->display, 0);
+    if (imfsample->copygc != None)
+      XFreeGC(imfsample->display, imfsample->copygc);
     if (imfsample->gc != None)
-      Tk_FreeGC(imfsample->display, imfsample->gc);
+      XFreeGC(imfsample->display, imfsample->gc);
     ckfree((char *) imfsample);
 }
 
@@ -641,5 +722,92 @@ int sx, sy;
 	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
 	}
     }
+    if (imfsample->with_emblem >= 0) {
+	ImageFamily *eimf = imfsample->imf_list[imfsample->with_emblem];
+	Image *eimg;
+	int ex, ey, ew, eh;
+
+	if (emblem_position(uimg, NULL, NULL, sw, sh, &ex, &ey, &ew, &eh)) {
+	    draw_one_emblem(imfsample, d, gc, eimf, sx + ex, sy + ey, ew, eh);
+	}
+    }
 }
 
+/* Draw a single image at a given location. */
+
+int
+draw_one_emblem(imfsample, d, gc, imf, sx, sy, sw, sh)
+Imfsample *imfsample;
+Drawable d;
+GC gc;
+ImageFamily *imf;
+int sx, sy;
+{
+    int sx2, sy2;
+    Image *eimg;
+    TkImage *tkimg;
+    Tk_Window tkwin = imfsample->tkwin;
+    Display *dpy = Tk_Display(tkwin);
+    XColor *imagecolor = black_color;
+    XColor *maskcolor = white_color;
+
+    eimg = best_image(imf, sw, sh);
+    if (eimg == NULL)
+      return;
+    if (!eimg->istile) {
+	/* Offset the image to draw in the middle of its area,
+	   whether larger or smaller than the given area. */
+	sx2 = sx + (sw - eimg->w) / 2;  sy2 = sy + (sh - eimg->h) / 2;
+	/* Only change the size of the rectangle being drawn if it's
+	   smaller than what was passed in. */
+	if (eimg->w < sw) {
+	    sx = sx2;
+	    sw = eimg->w;
+	}
+	if (eimg->h < sh) {
+	    sy = sy2;
+	    sh = eimg->h;
+	}
+    }
+    tkimg = (TkImage *) eimg->hook;
+    if (tkimg == NULL)
+      return;
+    XSetClipMask(dpy, gc, None);
+    XSetClipOrigin(dpy, gc, sx2, sy2);
+    XSetFillStyle(dpy, gc, FillSolid);
+    if (tkimg->colr != None && imfsample->show_color) {
+	if (eimg->istile) {
+	    XSetFillStyle(dpy, gc, FillTiled);
+	    XSetTile(dpy, gc, tkimg->colr);
+	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
+	} else {
+	    if (tkimg->mask != None && imfsample->show_masks) {
+		/* Use the image's mask to do clipped drawing. */
+		XSetClipMask(dpy, gc, tkimg->mask);
+	    }
+	    /* Draw the color image. */
+	    XCopyArea(dpy, tkimg->colr, d, gc, 0, 0, sw, sh, sx, sy);
+	}
+    } else if (tkimg->solid != NULL && imfsample->show_color) {
+	XSetForeground(dpy, gc, tkimg->solid->pixel);
+	XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
+    } else if (tkimg->mono != None || tkimg->mask != None) {
+	/* Set the color we're going to use for the mask; use the
+	   imagecolor if we'll be using the mask as the only image. */
+	XSetForeground(dpy, gc,
+		       (tkimg->mono == None ? imagecolor : maskcolor)->pixel);
+	/* Set the clip mask to be explicit mask or unit's image. */
+	if (tkimg->mask && imfsample->show_masks)
+	  XSetClipMask(dpy, gc, tkimg->mask);
+	else
+	  XSetClipMask(dpy, gc, tkimg->mono);
+	/* Draw the mask. */
+	XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
+	/* Draw the image proper. */
+	if (tkimg->mono != None) {
+	    XSetForeground(dpy, gc, imagecolor->pixel);
+	    XSetClipMask(dpy, gc, tkimg->mono);
+	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
+	}
+    }
+}
