@@ -22,11 +22,6 @@ any later version.  See the file COPYING.  */
 
 /* #define STUPIDFLUSH */
 
-/* This is the name of a family of programs, so argv[0] inadequate. */
-
-#define PROGRAMNAME "xconq"
-#define PROGRAMCLASSNAME "Xconq"
-
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
