@@ -1,5 +1,5 @@
 /* Definitions for the X11 Xt interface to Xconq.
-   Copyright (C) 1998 Stanley T. Shebs.
+   Copyright (C) 1998, 1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -8,6 +8,11 @@ any later version.  See the file COPYING.  */
 
 #include "xconq.h"
 
+/* This is the name of a family of programs, so argv[0] inadequate. */
+
+#define PROGRAMNAME "xtconq"
+#define PROGRAMCLASSNAME "Xtconq"
+
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Xaw/Box.h>
